<?php
/**
 * All the core functions
 *
 * @package Live Composer - WooCommerce integration
 */

// Prevent direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	header( 'HTTP/1.0 403 Forbidden' );
	exit;
}

/**
 * Add a class 'woocommerce' for Edit mode
 *
 * @param array $classes One or more classes to add to the class list.
 *
 * @return array
 */
function lcwoo_add_class( $classes ) {

	global $dslc_active;

	if ( $dslc_active ) {
		if ( isset( $_GET['page_id'] ) ) {
			$dslc_template = get_post_meta( get_the_ID(), 'dslc_template_for', true );

			if ( 'product' === $dslc_template || 'product_archive' === $dslc_template || 'woo-shop' === $dslc_template ) {
				$classes[] = 'woocommerce';
			}
		}
	} elseif ( 'dslc_templates' === get_post_type() ) {
		$id = get_the_ID();
		$dslc_template = get_post_meta( get_the_ID(), 'dslc_template_for', true );

		if ( 'product' === $dslc_template || 'product_archive' === $dslc_template || 'woo-shop' === $dslc_template ) {
			$classes[] = 'woocommerce';
		}
	}

	return $classes;
}
add_filter( 'body_class', 'lcwoo_add_class' );

/**
 * Add a class 'product' for Edit mode
 *
 * @param array $classes One or more classes to add to the class list.
 *
 * @return array
 */
function lcwoo_add_class_for_listing( $classes ) {

	global $dslc_active;

	if ( $dslc_active && 'product' === get_post_type() ) {
		$classes[] = 'product';
	}

	return $classes;
}
add_filter( 'post_class', 'lcwoo_add_class_for_listing' );

/**
 * Disable module 'Product Woo' in LC
 */
function lcwoo_disable_woocommerce_module() {
	dslc_unregister_module( 'DSLC_WooCommerce_Products' );
}
add_action( 'dslc_hook_unregister_modules', 'lcwoo_disable_woocommerce_module' );

/**
 * Shop messages
 */
function lcwoo_shop_messages() {
	if ( ! is_checkout() ) {
		echo wp_kses_post( lcwooo_do_shortcode( 'woocommerce_messages' ) );
	}
}
add_action( 'lcwoo_content_top', 'lcwoo_shop_messages', 15 );

/**
 * Add Shop Messages
 */
function lcwoo_shop_messages_add_top() {
	if ( is_cart() ) {
		do_action( 'lcwoo_content_top' );
	}
}
add_action( 'wp_head', 'lcwoo_shop_messages_add_top' );

/**
 * Call a shortcode function by tag name.
 *
 * @param string $tag     The shortcode whose function to call.
 * @param array  $atts    The attributes to pass to the shortcode function. Optional.
 * @param array  $content The shortcode's content. Default is null (none).
 *
 * @return string|bool False on failure, the result of the shortcode on success.
 */
function lcwooo_do_shortcode( $tag, array $atts = array(), $content = null ) {
	global $shortcode_tags;

	if ( ! isset( $shortcode_tags[ $tag ] ) ) {
		return false;
	}

	return call_user_func( $shortcode_tags[ $tag ], $atts, $content, $tag );
}

/**
 * Add Design for Pages
 */
function lcwoo_add_design_for_pages() {

	$woo_cart_page_id = get_option( 'woocommerce_cart_page_id' );
	$woo_checkout_page_id = get_option( 'woocommerce_checkout_page_id' );
	$woo_myaccount_page_id = get_option( 'woocommerce_myaccount_page_id' );

	if ( false === get_option( 'lcwoo_cart_page_flag' ) ) {
		require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/cart/design/page/dslc-code-cart.php' );
		add_option( 'lcwoo_cart_page_flag', '1' );
	}

	if ( false === get_option( 'lcwoo_checkout_page_flag' ) ) {
		require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/checkout/design/page/dslc-code-checkout.php' );
		add_option( 'lcwoo_checkout_page_flag', '1' );
	}

	if ( false === get_option( 'lcwoo_myaccount_page_flag' ) ) {
		require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/account/design/page/dslc-code-account.php' );
		add_option( 'lcwoo_myaccount_page_flag', '1' );
	}
}
add_action( 'admin_footer', 'lcwoo_add_design_for_pages' );

/**
 * Create default Woo Product Template in the LiveComposer Templates Section
 */
function lcwoo_create_product_template() {

	if ( false === get_option( 'lcwoo_templates' ) ) {

		$default_templates = array(
			'product' => array(
				'type' => 'product',
				'title' => 'Woo Product',
				'slug' => 'woo-product',
			),
			'shop' => array(
				'type' => 'woo-shop',
				'title' => 'Woo Shop',
				'slug' => 'woo-shop',
			),
			'listing' => array(
				'type' => 'product_archive',
				'title' => 'Woo Listing',
				'slug' => 'product_archive',
			),
		);

		add_option( 'lcwoo_templates', $default_templates );
	}

	if ( false === get_option( 'lcwoo_templates_flag' ) ) {

		global $wpdb;
		$woo_templates = ( $wpdb->get_results( "SELECT *  FROM `".$wpdb->prefix."posts` WHERE `post_type`='dslc_templates'", 'ARRAY_A' ) );
		$woo_template_found = false;

		$default_templates = get_option( 'lcwoo_templates' );

		foreach ( $default_templates as $template_key => $template ) {

			foreach ( $woo_templates as $woo_template ) {
				if ( $template['type'] === get_post_meta( $woo_template['ID'], 'dslc_template_for', true ) ) {
					$woo_template_found = true;
					break;
				}
			}

			if ( ! $woo_template_found ) {
				$woo = array(
					'post_title' => $template['title'],
					'post_name' => $template['slug'],
					'post_type'  => 'dslc_templates',
					'post_status'  => 'publish',
					'ping_status'  => 'closed',
				);
				$post_id = wp_insert_post( $woo );
				add_metadata( 'post', $post_id, 'dslc_template_for', $template['type'], true );
				add_metadata( 'post', $post_id, 'dslc_template_base', 'custom', true );
				add_metadata( 'post', $post_id, 'dslc_template_type', 'default', true );

				if ( 'product' === $template['type'] ) {
					require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/product/design/dslc-code-product.php' );
				} elseif ( 'woo-shop' === $template['type'] ) {
					require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/shop/design/page/dslc-code-shop.php' );
				} elseif ( 'product_archive' === $template['type'] ) {
					require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/shop/design/dslc-code-listing.php' );
				}
			}
		}

		add_option( 'lcwoo_templates_flag', '1' );
	}
}
add_action( 'admin_init', 'lcwoo_create_product_template' );

/**
 * Include Templates
 *
 * @param string $template Get current template.
 */
function lcwoo_include_templates( $template ) {
	if ( is_shop() ) {
		$template = LCWOO_INTEGRATION_PLUGIN_DIR.'includes/shop/templates/page/shop.php';
	} elseif ( is_product_category() || is_product_tag() ) {
		$template = LCWOO_INTEGRATION_PLUGIN_DIR.'includes/shop/templates/listing.php';
	}

	return $template;
}
add_filter( 'template_include', 'lcwoo_include_templates', 99 );

/**
 * Add Woo Template into the list of post Templates in the Live Composer
 * WordPress Admin > Appearance > Templates
 *
 * @param array $template Add New Template.
 */
function lcwoo_enable_product_template( $template ) {

	$template['product'] = 'Woo Product';
	$template['woo-shop'] = 'Woo Shop';

	return $template;

} add_filter( 'dslc_post_templates_post_types', 'lcwoo_enable_product_template' );

/**
 * Hide module
 *
 * @param bool   $module_active active module.
 * @param int    $page_id id page.
 * @param string $module_id id module.
 */
function lcwoo_hide_module( $module_active, $page_id, $module_id ) {

	$page_type = get_post_type( $page_id );

	if ( 'page' === $page_type ) {

		if ( 'LCWoo_Add_To_Cart' === $module_id ||
			 'LCWoo_Excerpt' === $module_id ||
			 'LCWoo_Image' === $module_id ||
			 'LCWoo_Meta' === $module_id ||
			 'LCWoo_Price' === $module_id ||
			 'LCWoo_Rating' === $module_id ||
			 'LCWoo_Related' === $module_id ||
			 'LCWoo_Sale_Flash' === $module_id ||
			 'LCWoo_Tabs' === $module_id ||
			 'LCWoo_Title' === $module_id ||
			 'LCWoo_Up_Sells' === $module_id ||
			 'LCWoo_View_Cart' === $module_id ||
			 'LCWoo_Listing' === $module_id
		) {

			$module_active = false;
			return $module_active;
		}
	} elseif ( 'dslc_templates' === $page_type ) {

		if ( 'LCWoo_Cart' === $module_id ||
			 'LCWoo_Checkout' === $module_id ||
			 'LCWoo_Account' === $module_id
		) {

			$module_active = false;
			return $module_active;
		}
	}

	return $module_active;

}
add_filter( 'dslc_modules_panel_item_class', 'lcwoo_hide_module', 10, 3 );

if ( ! function_exists( 'woocommerce_catalog_ordering' ) ) {

	/**
	 * Output the product sorting options.
	 */
	function lcwoo_catalog_ordering() {
		global $wp_query;

		$orderby                 = isset( $_GET['orderby'] ) ? wc_clean( $_GET['orderby'] ) : apply_filters( 'woocommerce_default_catalog_orderby', get_option( 'woocommerce_default_catalog_orderby' ) );
		$show_default_orderby    = 'menu_order' === apply_filters( 'woocommerce_default_catalog_orderby', get_option( 'woocommerce_default_catalog_orderby' ) );
		$catalog_orderby_options = apply_filters( 'woocommerce_catalog_orderby', array(
			'menu_order' => __( 'Default sorting', 'woocommerce' ),
			'popularity' => __( 'Sort by popularity', 'woocommerce' ),
			'rating'     => __( 'Sort by average rating', 'woocommerce' ),
			'date'       => __( 'Sort by newness', 'woocommerce' ),
			'price'      => __( 'Sort by price: low to high', 'woocommerce' ),
			'price-desc' => __( 'Sort by price: high to low', 'woocommerce' ),
		) );

		if ( ! $show_default_orderby ) {
			unset( $catalog_orderby_options['menu_order'] );
		}

		if ( 'no' === get_option( 'woocommerce_enable_review_rating' ) ) {
			unset( $catalog_orderby_options['rating'] );
		}

		wc_get_template( 'loop/orderby.php', array( 'catalog_orderby_options' => $catalog_orderby_options, 'orderby' => $orderby, 'show_default_orderby' => $show_default_orderby ) );
	}
}

/**
 * Get Woo Shop ID
 *
 * @param string $post_type_slug slug.
 */
function lcwoo_get_shop_id( $post_type_slug ) {

	$args = array(
	    'post_type'  => 'dslc_templates',
	    'meta_query' => array(
			array(
			    'key'     => 'dslc_template_for',
			    'value'   => 'woo-shop',
			),
			array(
			    'key'     => 'dslc_template_type',
			    'value'   => 'default',
			),
	    ),
	);

	$query = get_posts( $args );

	$template = $query[0];
	$template_id = $template->ID;

	return $template_id;
}
add_filter( 'dslc_post_type_slug', 'lcwoo_get_shop_id' );

/**
 * Change default description callback
 *
 * @param array $tabs tabs.
 */
function lcwoo_module_tabs_description_tab( $tabs ) {

	$tabs['description']['callback'] = 'lcwoo_module_tabs_description_content';	// Fixed Issue: https://github.com/lumbermandesigns/lc-woo-integration/issues/76

	return $tabs;
}
add_filter( 'woocommerce_product_tabs', 'lcwoo_module_tabs_description_tab', 98 );

function lcwoo_module_tabs_description_content() {

	$heading = esc_html( apply_filters( 'woocommerce_product_description_heading', __( 'Description', 'woocommerce' ) ) );

	if ( $heading ) {
		echo $heading;
	}

	$content = get_the_content();
	echo $content;
}