<?php
/**
 * Module Sale Flash
 *
 * @package Live Composer - WooCommerce integration
 */

// Prevent direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	header( 'HTTP/1.0 403 Forbidden' );
	exit;
}

/**
 * Module Class
 */
class LCWoo_Sale_Flash extends DSLC_Module {

	/**
	 * Unique module id
	 *
	 * @var string
	 */
	var $module_id;

	/**
	 * Module label to show in the page builder
	 *
	 * @var string
	 */
	var $module_title;

	/**
	 * Module icon name (FontAwesome)
	 *
	 * @var string
	 */
	var $module_icon;

	/**
	 * Section in the modules panel that includes this module
	 *
	 * @var string
	 */
	var $module_category;

	/**
	 * Exclude from main listing
	 *
	 * @var string
	 */
	var $exclude_from_main_listing;

	/**
	 * Construct
	 */
	function __construct() {

		$this->module_id = 'LCWoo_Sale_Flash';
		$this->module_title = __( 'Sale Flash', 'lc-woo-integration' );
		$this->module_icon = 'tag';
		$this->module_category = 'Woo Product';
		$this->exclude_from_main_listing = true;
	}

	/**
	 * Options
	 */
	function options() {
		$options = array(

			array(
				'label' => __( 'Show On', 'lc-woo-integration' ),
				'id' => 'css_show_on',
				'std' => 'desktop tablet phone',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Desktop', 'lc-woo-integration' ),
						'value' => 'desktop',
					),
					array(
						'label' => __( 'Tablet', 'lc-woo-integration' ),
						'value' => 'tablet',
					),
					array(
						'label' => __( 'Phone', 'lc-woo-integration' ),
						'value' => 'phone',
					),
				),
			),

			/**
			 * General
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_sale_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-sale span.onsale',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_main_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_sale_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_sale_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_sale_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_sale_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_main_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_main_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_main_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_main_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_main_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_main_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_main_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_main_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_main_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_main_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_main_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_main_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_main_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
			),

			/**
			 * Typography
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_sale_text_align',
				'std' => 'left',
				'type' => 'select',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-sale span.onsale',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
				'choices' => array(
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
					array(
						'label' => __( 'Center', 'lc-woo-integration' ),
						'value' => 'center',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Justify', 'lc-woo-integration' ),
						'value' => 'justify',
					),
				),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_sale_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_sale_color',
					'std' => '#000',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_sale_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_sale_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_sale_line_height',
					'std' => '25',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Text Transform', 'lc-woo-integration' ),
					'id' => 'css_sale_text_transform',
					'std' => 'none',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => __( 'None', 'lc-woo-integration' ),
							'value' => 'none',
						),
						array(
							'label' => __( 'Capitalize', 'lc-woo-integration' ),
							'value' => 'capitalize',
						),
						array(
							'label' => __( 'Uppercase', 'lc-woo-integration' ),
							'value' => 'uppercase',
						),
						array(
							'label' => __( 'Lowercase', 'lc-woo-integration' ),
							'value' => 'lowercase',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'text-transform',
					'section' => 'styling',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_sale_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),

			/**
			 * Responsive Tablet
			 */

			array(
				'label' => __( 'Responsive', 'lc-woo-integration' ),
				'id' => 'css_res_t',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_main_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_main_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_main_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_main_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_sale_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-sale span.onsale',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_sale_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-sale span.onsale',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_res_t_sale_text_align',
				'std' => 'left',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-sale span.onsale',
				'affect_on_change_rule' => 'text-align',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),

			/**
			 * Responsive Phone
			 */

			array(
				'label' => __( 'Responsive', 'lc-woo-integration' ),
				'id' => 'css_res_p',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_main_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_main_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_main_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-sale span.onsale',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_main_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_sale_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-sale span.onsale',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_sale_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-sale span.onsale',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_res_p_sale_text_align',
				'std' => 'left',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-sale span.onsale',
				'affect_on_change_rule' => 'text-align',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),

		);

		$options = array_merge( $options, $this->shared_options( 'animation_options' ) );
		$options = array_merge( $options, $this->presets_options() );

		return apply_filters( 'dslc_module_options', $options, $this->module_id );
	}

	/**
	 * Module HTML output.
	 *
	 * @param  array $options Module options to fill the module template.
	 */
	function output( $options ) {

		$this->module_start( $options );

		global $dslc_active;

		if ( isset( $_POST['dslc_post_id'] ) ) {
			$page_id = $_POST['dslc_post_id'];
		} elseif ( isset( $_GET['dslc_post_id'] ) ) {
			$page_id = $_GET['dslc_post_id'];
		} else {
			$page_id = get_the_ID();
		}

		if ( 'dslc_templates' === get_post_type() || ( $dslc_active && 'dslc_templates' === get_post_type( $page_id ) ) ) {
			if ( is_shop() || is_product_category() || is_product_tag() ) { ?>
				<div class="dslc-notification dslc-red">
					<?php esc_html_e( 'This module needs to be used just on the WooCommerce product pages only.', 'lc-woo-integration' ); ?>
				</div>
			<?php } else {
				?>
				<div class="woocommerce-sale">
					<span class="onsale">Sale!</span>
				</div>
				<?php
			}
		} else {
			if ( is_product() ) {
			?>
				<div class="woocommerce-sale">
					<?php
						/**
						 * Front-end without LC in editing mode. Output the product sale flash using standard WooCommerce function.
						 */
						woocommerce_show_product_sale_flash();
					?>
				</div>
			<?php
			} else {
				if ( $dslc_active ) {
				?>
					<div class="dslc-notification dslc-red">
						<?php esc_html_e( 'This module needs to be used just on the WooCommerce product pages only.', 'lc-woo-integration' ); ?>
					</div>
				<?php
				}
			}
		}

		$this->module_end( $options );
	}
}

/**
 * Register Module
 */
add_action('dslc_hook_register_modules',
	create_function( '', 'return dslc_register_module( "LCWoo_Sale_Flash" );' )
);
