<?php
/**
 *  Plugin Name: Live Composer - WooCommerce integration
 *  Plugin URI: https://livecomposerplugin.com/add-ons/?utm_source=lc-woo-integration&utm_medium=wp-admin/plugins-list&utm_campaign=plugin_uri
 *  Description: Create a fully customizable WooCoomerce website using drag and drop builder.
 *  Version: 1.2.3
 *  Author: Live Composer Team
 *  Author URI: https://livecomposerplugin.com/?utm_source=lc-woo-integration&utm_medium=wp-admin/plugins-list&utm_campaign=author_uri
 *  License: GPL2
 *  License URI: https://www.gnu.org/licenses/gpl-2.0.html
 *  Domain Path: /lang
 *
 *  Live Composer - WooCommerce integration Plugin is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Live Composer - WooCommerce integration Plugin. If not, see <http://www.gnu.org/licenses/>.
 *
 *  @package Live Composer - WooCommerce integration
 */

// Prevent direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	header( 'HTTP/1.0 403 Forbidden' );
	exit;
}

/**
 * Run plugin only if the Live Composer and WooCommerce plugin is active
 */
function lcwoo_plugin_init() {

	if ( class_exists( 'WooCommerce' ) && class_exists( 'DSLC_Module' ) ) {

		$woocommerce_version = WC()->version;

		if ( version_compare( DS_LIVE_COMPOSER_VER, '1.3', '>=' ) ) {

			if ( version_compare( $woocommerce_version, '3.0.0', '>=' ) ) {

				define( 'LCWOO_INTEGRATION_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
				define( 'LCWOO_INTEGRATION_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
				define( 'LCWOO_INTEGRATION_PLUGIN_VER', '1.2.3' );

				// This is the URL our updater / license checker pings. This should be the URL of the site with EDD installed
				// IMPORTANT: change the name of this constant to something unique to prevent conflicts with other plugins using this system.
				define( 'EDD_LCWOO_STORE_URL', 'https://livecomposerplugin.com' );

				// The name of your product. This is the title of your product in EDD and should match the download title in EDD exactly
				// IMPORTANT: change the name of this constant to something unique to prevent conflicts with other plugins using this system.
				define( 'EDD_LCWOO_ITEM_NAME', 'WooCommerce Integration' );

				// The name of the settings page for the license input to be displayed.
				define( 'EDD_LCWOO_LICENSE_PAGE', 'dslc_options_woo_license' );

				// Load EDD custom updater.
				if ( ! class_exists( 'EDD_LCWOO_Plugin_Updater' ) ) {
					include( dirname( __FILE__ ) . '/includes/common/EDD_LCWOO_Plugin_Updater.php' );
				}

				/**
				 * Setup the updater.
				 */
				function lcwoo_edd_updater() {

					// Retrieve our license key from the DB.
					$license_key = trim( get_option( 'lcwoo_edd_license_key' ) );

					// Setup the updater.
					$edd_updater = new EDD_LCWOO_Plugin_Updater( EDD_LCWOO_STORE_URL, __FILE__, array(
							'version' 	=> '1.2.3', 		// Current version number.
							'license' 	=> $license_key, 	// license key (used get_option above to retrieve from DB).
							'item_name' => EDD_LCWOO_ITEM_NAME, 	// name of this plugin.
							'author' 	=> 'Live Composer Team',  // Author of this plugin.
							'url'       => home_url(),
						)
					);
				}
				add_action( 'admin_init', 'lcwoo_edd_updater', 0 );

				/**
				 * Updater
				 */
				require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/common/updater.php' );

				add_theme_support( 'woocommerce' ); // Hide message - Declare WooCommerce support in third party theme.

				/**
				 * Include required core files
				 */
				require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/product/lc-woo-product.php' );
				require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/shop/lc-woo-shop.php' );
				require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/cart/lc-woo-cart.php' );
				require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/checkout/lc-woo-checkout.php' );
				require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/account/lc-woo-account.php' );
				require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/common/functions.php' );
			} else {

				/**
				 * Admin Notice
				 */
				function lcwoo_notice_woo_version() {
				?>
				<div class="notice notice-error">
					<p><?php printf( __( 'The "Live Composer - WooCommerce integration" add-on requires WooCommerce 3.0+. %sContact our support team%s if you need a previous version.', 'lcwoo' ), '<a target="_blank" href="https://livecomposerplugin.com/support/">', '</a>' ); ?></p>
				</div>
				<?php }
				add_action( 'admin_notices', 'lcwoo_notice_woo_version' );
			}
		} else {

			/**
			 * Admin Notice
			 */
			function lcwoo_notice_lc_version() {
			?>
			<div class="notice notice-error">
				<p><?php printf( __( 'The "Live Composer - WooCommerce integration" add-on requires Live Composer version 1.3+. %sContact our support team%s if you need a previous version.', 'lcwoo' ), '<a target="_blank" href="https://livecomposerplugin.com/support/">', '</a>' ); ?></p>
			</div>
			<?php }
			add_action( 'admin_notices', 'lcwoo_notice_lc_version' );
		}
	} else {

		/**
		 * Admin Notice
		 */
		function lcwoo_inactive_notice() {
		?>
		<div class="error">
			<p><?php printf( __( 'The Woocommerce extension for Live Composer is activated but in order to work, need to have both %sWooCommerce%s and %sLive Composer%s plugins should be active.', 'lcwoo' ), '<a target="_blank" href="https://wordpress.org/plugins/woocommerce/">', '</a>', '<a target="_blank" href="https://wordpress.org/plugins/live-composer-page-builder/">', '</a>' ); ?></p>
		</div>
		<?php }
		add_action( 'admin_notices', 'lcwoo_inactive_notice' );
	}
}
add_action( 'plugins_loaded', 'lcwoo_plugin_init' );
