<?php
/**
 * Module Account
 *
 * @package Live Composer - WooCommerce integration
 */

// Prevent direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	header( 'HTTP/1.0 403 Forbidden' );
	exit;
}

/**
 * Get query vars
 *
 * @param  array $query_vars Select module template.
 */
function lcwoo_account_request( $query_vars ) {

	global $dslc_active;

	if ( $dslc_active ) {

		$ref = $_SERVER['HTTP_REFERER'];
		$query_params = parse_url( $ref, PHP_URL_QUERY );

		if ( $query_params ) {

		    parse_str( $query_params, $values );

		    if ( isset( $values['orders'] ) ) {
		        $query_vars['orders'] = '';
		    } elseif ( isset( $values['view-order'] ) ) {
		    	$query_vars['view-order'] = $values['view-order'];
		    } elseif ( isset( $values['downloads'] ) ) {
		    	$query_vars['downloads'] = '';
		    } elseif ( isset( $values['edit-address'] ) && empty( $values['edit-address'] ) ) {
		    	$query_vars['edit-address'] = '';
		    } elseif ( isset( $values['edit-address'] ) && ( 'billing' === $values['edit-address'] ) ) {
		    	$query_vars['edit-address'] = 'billing';
		    } elseif ( isset( $values['edit-address'] ) && ( 'shipping' === $values['edit-address'] ) ) {
		    	$query_vars['edit-address'] = 'shipping';
		    } elseif ( isset( $values['edit-account'] ) ) {
		    	$query_vars['edit-account'] = '';
		    }
		}
	}

	return $query_vars;
}
add_filter( 'request', 'lcwoo_account_request' );

/**
 * Module Class
 */
class LCWoo_Account extends DSLC_Module {

	/**
	 * Unique module id
	 *
	 * @var string
	 */
	var $module_id;

	/**
	 * Module label to show in the page builder
	 *
	 * @var string
	 */
	var $module_title;

	/**
	 * Module icon name (FontAwesome)
	 *
	 * @var string
	 */
	var $module_icon;

	/**
	 * Section in the modules panel that includes this module
	 *
	 * @var string
	 */
	var $module_category;

	/**
	 * Exclude from main listing
	 *
	 * @var string
	 */
	var $exclude_from_main_listing;

	/**
	 * Construct
	 */
	function __construct() {

		$this->module_id = 'LCWoo_Account';
		$this->module_title = __( 'Account', 'lc-woo-integration' );
		$this->module_icon = 'user';
		$this->module_category = 'Woo Account';
		$this->exclude_from_main_listing = true;
	}

	/**
	 * Options
	 */
	function options() {
		$options = array(

			array(
				'label' => __( 'Show On', 'lc-woo-integration' ),
				'id' => 'css_show_on',
				'std' => 'desktop tablet phone',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Desktop', 'lc-woo-integration' ),
						'value' => 'desktop',
					),
					array(
						'label' => __( 'Tablet', 'lc-woo-integration' ),
						'value' => 'tablet',
					),
					array(
						'label' => __( 'Phone', 'lc-woo-integration' ),
						'value' => 'phone',
					),
				),
			),
			array(
				'label' => __( 'Error-Proof Mode', 'lc_masterslider' ),
				'id' => 'error_proof_mode',
				'std' => 'active',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Enabled', 'lc_masterslider' ),
						'value' => 'active',
					),
				),
				'help' => __( 'Some JavaScript code and shortcodes can break the page editing.<br> Use <b>Error-Proof Mode</b> to make it work.', 'lc_masterslider' ),
				'visibility' => 'hidden',
			),

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_general_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_general_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_general_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_general_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_general_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_general_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_general_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_general_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_general_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_general_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_general_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_general_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_general_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_general_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_general_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_general_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_general_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_general_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_general_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
			),

			/**
			 * Navigation
			 */

			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_navigation_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Navigation', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_navigation_border_color',
					'std' => 'rgba(0,0,0,.05)',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account ul li',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Navigation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_navigation_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account ul li',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Navigation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_navigation_border_trbl',
					'std' => 'top',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account ul li',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Navigation', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_navigation_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Navigation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_navigation_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Navigation', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_navigation_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account ul li a',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Navigation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Color: Hover', 'lc-woo-integration' ),
					'id' => 'css_navigation_color_hover',
					'std' => '#a1a2a5',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account ul li a:hover',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Navigation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_navigation_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account ul li a',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Navigation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_navigation_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account ul li a',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Navigation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_navigation_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account ul li a',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Navigation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_navigation_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account ul li a',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Navigation', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_navigation_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Navigation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_navigation_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Navigation', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_navigation_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '11',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account ul li a',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Navigation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_navigation_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account ul li a',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Navigation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_navigation_padding_bottom',
					'onlypositive' => true,
					'std' => '11',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account ul li a',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Navigation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_navigation_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account ul li a',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Navigation', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_navigation_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Navigation', 'lc-woo-integration' ),
			),

			/**
			 * Typography
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_typography_text_align',
				'std' => 'left',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account p',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_typography_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_typography_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account p',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Link - Color', 'lc-woo-integration' ),
					'id' => 'css_typography_link_color',
					'std' => '#96588a',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account p a, .lcwoo_account p strong',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_typography_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account p',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_typography_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account p',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Link - Font Weight', 'lc-woo-integration' ),
					'id' => 'css_typography_link_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account p a, .lcwoo_account p strong',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_typography_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account p',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_typography_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account p',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_typography_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_typography_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_typography_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account p',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_typography_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account p',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_typography_margin_bottom',
					'std' => '30',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account p',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_typography_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account p',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_typography_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_typography_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_typography_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_typography_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_typography_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_typography_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Typography', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_typography_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),

			/**
			 * Form > Title
			 */

			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_title_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_form_title_color',
					'std' => '#484c51',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form h3',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_form_title_font_size',
					'std' => '22',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form h3',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_form_title_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form h3',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_form_title_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form h3',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_form_title_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form h3',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_title_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_title_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_form_title_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form h3',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_form_title_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form h3',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_form_title_margin_bottom',
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form h3',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_form_title_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form h3',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_title_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Title', 'lc-woo-integration' ),
			),

			/**
			 * Form > Label
			 */

			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_label_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Label', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_form_label_color',
					'std' => '#43454b',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .form-row label',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_form_label_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .form-row label',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_form_label_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .form-row label',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_form_label_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .form-row label',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_form_label_line_height',
					'std' => '23',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .form-row label',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_label_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_label_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Label', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_form_label_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .form-row label',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_form_label_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .form-row label',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_form_label_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .form-row label',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_form_label_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .form-row label',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_label_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Label', 'lc-woo-integration' ),
			),

			/**
			 * Form > Input
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_form_input_bg_color',
				'std' => '#f2f2f2',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account form input',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Form > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_form_input_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Input', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_form_input_border_color',
					'std' => 'rgba(0,0,0,0.125)',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form input',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Form > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_form_input_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form input',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_form_input_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form input',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Form > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_form_input_border_radius',
					'std' => '2',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form input',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Input', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_form_input_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_input_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Input', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_form_input_color',
					'std' => '#43454b',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form input',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Form > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_form_input_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form input',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_form_input_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form input',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Form > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_form_input_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form input',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Form > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_form_input_line_height',
					'std' => '23',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form input',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Input', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_input_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_input_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Input', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_form_input_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form p.form-row',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Form > Input', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_form_input_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form p.form-row',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Form > Input', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_form_input_margin_bottom',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form p.form-row',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Form > Input', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_form_input_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form p.form-row',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Form > Input', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_input_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_form_input_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Input', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_form_input_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form input',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_form_input_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form input',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_form_input_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form input',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_form_input_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form input',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Input', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_form_input_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Input', 'lc-woo-integration' ),
			),

			/**
			 * Form > Button
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_form_button_bg_color',
				'std' => '#9a4f8c',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account form .button',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Form > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color: Hover', 'lc-woo-integration' ),
				'id' => 'css_form_button_bg_color_hover',
				'std' => '#7d3f71',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account form .button:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Form > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_form_button_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_form_button_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .button',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Form > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_form_button_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .button',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_form_button_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .button',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Form > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_form_button_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .button',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_form_button_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_button_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_form_button_color',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .button',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Form > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Color: Hover', 'lc-woo-integration' ),
					'id' => 'css_form_button_color_hover',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .button:hover',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Form > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_form_button_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .button',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_form_button_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .button',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Form > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_form_button_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .button',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Form > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_form_button_line_height',
					'std' => '23',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .button',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_button_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_form_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_form_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .button',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_form_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .button',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_form_button_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .button',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_form_button_padding_left',
					'onlypositive' => true,
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form .button',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_form_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Button', 'lc-woo-integration' ),
			),

			/**
			 * Form > Fieldset > Legend
			 */

			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_fieldset_legend_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Fieldset > Legend', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_form_fieldset_legend_color',
					'std' => '#43454b',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form fieldset legend',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Form > Fieldset > Legend', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_form_fieldset_legend_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form fieldset legend',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Fieldset > Legend', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_form_fieldset_legend_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form fieldset legend',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Form > Fieldset > Legend', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_form_fieldset_legend_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form fieldset legend',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Form > Fieldset > Legend', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_form_fieldset_legend_line_height',
					'std' => '23',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account form fieldset legend',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Fieldset > Legend', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_fieldset_legend_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Fieldset > Legend', 'lc-woo-integration' ),
			),

			/**
			 * Info
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_account_info_bg_color',
				'std' => '#3D9CD2',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_account_info_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_account_info_border_color',
					'std' => 'rgba(0,0,0, 0.15)',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_account_info_border_width',
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_account_info_border_trbl',
					'std' => 'left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_account_info_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_account_info_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_account_info_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_account_info_color',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_account_info_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_account_info_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_account_info_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_account_info_line_height',
					'std' => '31',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_account_info_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),

			/**
			 * Info > Button
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_account_info_button_bg_color',
				'std' => 'rgba(0,0,0,0)',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info .button',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Info > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_account_info_button_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_account_info_button_border_color',
					'std' => 'rgba(255,255,255,0.25)',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info .button',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_account_info_button_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info .button',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_account_info_button_border_trbl',
					'std' => 'left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info .button',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_account_info_button_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info .button',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_account_info_button_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_account_info_button_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_account_info_button_color',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info .button',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_account_info_button_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info .button',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_account_info_button_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info .button',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_account_info_button_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info .button',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_account_info_button_line_height',
					'std' => '31',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info .button',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_account_info_button_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_account_info_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_account_info_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info .button',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_account_info_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info .button',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_account_info_button_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info .button',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_account_info_button_padding_left',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .woocommerce-MyAccount-content .woocommerce-info .button',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_account_info_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info > Button', 'lc-woo-integration' ),
			),

			/**
			 * Order > H2
			 */

			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_order_h2_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > H2', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_order_h2_color',
					'std' => '#484c51',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account h2',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Order > H2', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_order_h2_font_size',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account h2',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > H2', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_order_h2_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account h2',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Order > H2', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_order_h2_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account h2',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Order > H2', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_order_h2_line_height',
					'std' => '26',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account h2',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > H2', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_order_h2_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > H2', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_order_h2_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > H2', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_order_h2_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account h2',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Order > H2', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_order_h2_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account h2',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Order > H2', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_order_h2_margin_bottom',
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account h2',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Order > H2', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_order_h2_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account h2',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Order > H2', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_order_h2_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > H2', 'lc-woo-integration' ),
			),

			/**
			 * Order > Table > Title
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_order_table_title_text_align',
				'std' => 'left',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account table.order_details thead tr th, .lcwoo_account table.my_account_orders thead tr th',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_order_table_title_bg_color',
				'std' => '#f8f8f8',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account table.order_details thead tr th, .lcwoo_account table.my_account_orders thead tr th',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_order_table_title_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_order_table_title_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details thead tr th, .lcwoo_account table.my_account_orders thead tr th',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_order_table_title_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details thead tr th, .lcwoo_account table.my_account_orders thead tr th',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_order_table_title_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details thead tr th, .lcwoo_account table.my_account_orders thead tr th',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_order_table_title_border_trbl',
					'std' => 'bottom',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details thead tr th, .lcwoo_account table.my_account_orders thead tr th',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_order_table_title_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_order_table_title_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_order_table_title_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details thead tr th, .lcwoo_account table.my_account_orders thead tr th',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_order_table_title_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details thead tr th, .lcwoo_account table.my_account_orders thead tr th',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_order_table_title_font_weight',
					'std' => '500',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details thead tr th, .lcwoo_account table.my_account_orders thead tr th',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_order_table_title_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details thead tr th, .lcwoo_account table.my_account_orders thead tr th',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_order_table_title_line_height',
					'std' => '21',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details thead tr th, .lcwoo_account table.my_account_orders thead tr th',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Text Transform', 'lc-woo-integration' ),
					'id' => 'css_order_table_title_text_transform',
					'std' => 'uppercase',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => __( 'None', 'lc-woo-integration' ),
							'value' => 'none',
						),
						array(
							'label' => __( 'Capitalize', 'lc-woo-integration' ),
							'value' => 'capitalize',
						),
						array(
							'label' => __( 'Uppercase', 'lc-woo-integration' ),
							'value' => 'uppercase',
						),
						array(
							'label' => __( 'Lowercase', 'lc-woo-integration' ),
							'value' => 'lowercase',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details thead tr th, .lcwoo_account table.my_account_orders thead tr th',
					'affect_on_change_rule' => 'text-transform',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_order_table_title_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_order_table_title_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_order_table_title_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details thead tr th, .lcwoo_account table.my_account_orders thead tr th',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_order_table_title_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details thead tr th, .lcwoo_account table.my_account_orders thead tr th',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_order_table_title_padding_bottom',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details thead tr th, .lcwoo_account table.my_account_orders thead tr th',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_order_table_title_padding_left',
					'onlypositive' => true,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details thead tr th, .lcwoo_account table.my_account_orders thead tr th',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_order_table_title_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Title', 'lc-woo-integration' ),
			),

			/**
			 * Order > Table > Item
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_order_table_item_text_align',
				'std' => 'left',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td, .lcwoo_account table.my_account_orders tbody tr td',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_order_table_item_bg_color',
				'std' => '#fdfdfd',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td, .lcwoo_account table.my_account_orders tbody tr td',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_order_table_item_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_order_table_item_border_color',
					'std' => '#fdfdfd',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td, .lcwoo_account table.my_account_orders tbody tr td',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_order_table_item_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td, .lcwoo_account table.my_account_orders tbody tr td',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_order_table_item_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td, .lcwoo_account table.my_account_orders tbody tr td',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_order_table_item_border_trbl',
					'std' => 'top',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td, .lcwoo_account table.my_account_orders tbody tr td',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_order_table_item_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_order_table_item_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_order_table_item_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td, .lcwoo_account table.my_account_orders tbody tr td',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Link - Color', 'lc-woo-integration' ),
					'id' => 'css_order_table_item_link_color',
					'std' => '#96588a',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td a, .lcwoo_account table.my_account_orders tbody tr td a',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Link - Color: Hover', 'lc-woo-integration' ),
					'id' => 'css_order_table_item_link_color_hover',
					'std' => '#96588a',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td a:hover, .lcwoo_account table.my_account_orders tbody tr td a:hover',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_order_table_item_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td, .lcwoo_account table.my_account_orders tbody tr td',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_order_table_item_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td, .lcwoo_account table.my_account_orders tbody tr td',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Link - Font Weight', 'lc-woo-integration' ),
					'id' => 'css_order_table_item_link_font_weight',
					'std' => '500',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td a, .lcwoo_account table.my_account_orders tbody tr td a',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_order_table_item_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td, .lcwoo_account table.my_account_orders tbody tr td',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_order_table_item_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td, .lcwoo_account table.my_account_orders tbody tr td',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Text Transform', 'lc-woo-integration' ),
					'id' => 'css_order_table_item_text_transform',
					'std' => 'none',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => __( 'None', 'lc-woo-integration' ),
							'value' => 'none',
						),
						array(
							'label' => __( 'Capitalize', 'lc-woo-integration' ),
							'value' => 'capitalize',
						),
						array(
							'label' => __( 'Uppercase', 'lc-woo-integration' ),
							'value' => 'uppercase',
						),
						array(
							'label' => __( 'Lowercase', 'lc-woo-integration' ),
							'value' => 'lowercase',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td, .lcwoo_account table.my_account_orders tbody tr td',
					'affect_on_change_rule' => 'text-transform',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_order_table_item_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_order_table_item_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_order_table_item_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td, .lcwoo_account table.my_account_orders tbody tr td',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_order_table_item_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td, .lcwoo_account table.my_account_orders tbody tr td',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_order_table_item_padding_bottom',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td, .lcwoo_account table.my_account_orders tbody tr td',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_order_table_item_padding_left',
					'onlypositive' => true,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td, .lcwoo_account table.my_account_orders tbody tr td',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_order_table_item_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Item', 'lc-woo-integration' ),
			),

			/**
			 * Order > Table > Item > Variation
			 */

			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_order_table_table_item_variation_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Item > Variation', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'One - Color', 'lc-woo-integration' ),
					'id' => 'css_order_table_table_item_variation_one_color',
					'std' => '#60646c',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td dl.variation dt, .lcwoo_account table.my_account_orders tbody tr td dl.variation dt',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Item > Variation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'One - Font Size', 'lc-woo-integration' ),
					'id' => 'css_order_table_table_item_variation_one_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td dl.variation dt, .lcwoo_account table.my_account_orders tbody tr td dl.variation dt',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Item > Variation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'One - Font Weight', 'lc-woo-integration' ),
					'id' => 'css_order_table_table_item_variation_one_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td dl.variation dt, .lcwoo_account table.my_account_orders tbody tr td dl.variation dt',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Order > Table > Item > Variation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'One - Line Height', 'lc-woo-integration' ),
					'id' => 'css_order_table_table_item_variation_one_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td dl.variation dt, .lcwoo_account table.my_account_orders tbody tr td dl.variation dt',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Item > Variation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Two - Color', 'lc-woo-integration' ),
					'id' => 'css_order_table_table_item_variation_two_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td dl.variation dd p, .lcwoo_account table.my_account_orders tbody tr td dl.variation dd p',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Item > Variation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Two - Font Size', 'lc-woo-integration' ),
					'id' => 'css_order_table_table_item_variation_two_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td dl.variation dd p, .lcwoo_account table.my_account_orders tbody tr td dl.variation dd p',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Item > Variation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Two - Font Weight', 'lc-woo-integration' ),
					'id' => 'css_order_table_table_item_variation_two_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td dl.variation dd p, .lcwoo_account table.my_account_orders tbody tr td dl.variation dd p',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Order > Table > Item > Variation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Two - Line Height', 'lc-woo-integration' ),
					'id' => 'css_order_table_table_item_variation_two_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td dl.variation dd p, .lcwoo_account table.my_account_orders tbody tr td dl.variation dd p',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Item > Variation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_order_table_table_item_variation_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td dl.variation',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Item > Variation', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_order_table_table_item_variation_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Item > Variation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_order_table_table_item_variation_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Item > Variation', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_order_table_table_item_variation_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td dl.variation dd p, .lcwoo_account table.my_account_orders tbody tr td dl.variation dd p',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Item > Variation', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_order_table_table_item_variation_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td dl.variation dd p, .lcwoo_account table.my_account_orders tbody tr td dl.variation dd p',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Item > Variation', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_order_table_table_item_variation_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td dl.variation dd p, .lcwoo_account table.my_account_orders tbody tr td dl.variation dd p',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Item > Variation', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_order_table_table_item_variation_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.order_details tbody tr td dl.variation dd p, .lcwoo_account table.my_account_orders tbody tr td dl.variation dd p',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Item > Variation', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_order_table_table_item_variation_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Item > Variation', 'lc-woo-integration' ),
			),

			/**
			 * Order > Table > Cart > Title
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_order_table_cart_title_text_align',
				'std' => 'left',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account tfoot tr th',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_order_table_cart_bg_color',
				'std' => '#f8f8f8',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account tfoot tr',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_order_table_cart_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_border_color',
					'std' => '#f8f8f8',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr th, .lcwoo_account tfoot tr td',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr th, .lcwoo_account tfoot tr td',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr th, .lcwoo_account tfoot tr td',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_border_trbl',
					'std' => 'top',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr th, .lcwoo_account tfoot tr td',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_order_table_cart_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_order_table_cart_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_title_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr th',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_title_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr th',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_title_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr th',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_title_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr th',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_title_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr th',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_order_table_cart_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_order_table_cart_title_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_title_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr th',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_title_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr th',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_title_padding_bottom',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr th',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_title_padding_left',
					'onlypositive' => true,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr th',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_order_table_cart_title_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_order_table_cart_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.shop_table',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.shop_table',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_margin_bottom',
					'std' => '40',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.shop_table',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.shop_table',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_order_table_cart_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Cart > Title', 'lc-woo-integration' ),
			),

			/**
			 * Order > Table > Cart > Item
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_order_table_cart_item_text_align',
				'std' => 'left',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account tfoot tr td',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_order_table_cart_item_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Cart > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_item_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr td',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_item_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr td',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_item_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr td',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Order > Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_item_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr td',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Order > Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_item_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr td',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Cart > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_order_table_cart_item_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_order_table_cart_item_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Cart > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_item_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr td',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_item_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr td',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_item_padding_bottom',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr td',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_order_table_cart_item_padding_left',
					'onlypositive' => true,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account tfoot tr td',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Table > Cart > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_order_table_cart_item_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > Table > Cart > Item', 'lc-woo-integration' ),
			),

			/**
			 * Order > Button
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_order_button_bg_color',
				'std' => '#9a4f8c',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-orders .order-actions a, .lcwoo_account .woocommerce-MyAccount-content .order-again a',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Order > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color: Hover', 'lc-woo-integration' ),
				'id' => 'css_order_button_bg_color_hover',
				'std' => '#7d3f71',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-orders .order-actions a:hover, .lcwoo_account .woocommerce-MyAccount-content .order-again a:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Order > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_order_button_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_order_button_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-orders .order-actions a, .lcwoo_account .woocommerce-MyAccount-content .order-again a',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_order_button_border_width',
					'std' => '',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-orders .order-actions a, .lcwoo_account .woocommerce-MyAccount-content .order-again a',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_order_button_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-orders .order-actions a, .lcwoo_account .woocommerce-MyAccount-content .order-again a',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_order_button_border_trbl',
					'std' => 'top',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-orders .order-actions a, .lcwoo_account .woocommerce-MyAccount-content .order-again a',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Order > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_order_button_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_order_button_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_order_button_color',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-orders .order-actions a, .lcwoo_account .woocommerce-MyAccount-content .order-again a',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Color: Hover', 'lc-woo-integration' ),
					'id' => 'css_order_button_color_hover',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-orders .order-actions a:hover, .lcwoo_account .woocommerce-MyAccount-content .order-again a:hover',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_order_button_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-orders .order-actions a, .lcwoo_account .woocommerce-MyAccount-content .order-again a',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_order_button_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-orders .order-actions a, .lcwoo_account .woocommerce-MyAccount-content .order-again a',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_order_button_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-orders .order-actions a, .lcwoo_account .woocommerce-MyAccount-content .order-again a',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_order_button_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-orders .order-actions a, .lcwoo_account .woocommerce-MyAccount-content .order-again a',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_order_button_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_order_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Order > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_order_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-orders .order-actions a, .lcwoo_account .woocommerce-MyAccount-content .order-again a',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_order_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-orders .order-actions a, .lcwoo_account .woocommerce-MyAccount-content .order-again a',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_order_button_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-orders .order-actions a, .lcwoo_account .woocommerce-MyAccount-content .order-again a',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_order_button_padding_left',
					'onlypositive' => true,
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-orders .order-actions a, .lcwoo_account .woocommerce-MyAccount-content .order-again a',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Order > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_order_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Order > Button', 'lc-woo-integration' ),
			),

			/**
			 * Customer Details
			 */

			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_customer_details_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Customer Details', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_customer_details_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Customer Details', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_customer_details_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_customer_details_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_customer_details_trbl',
					'std' => 'top right bottom',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Customer Details', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_customer_details_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Customer Details', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_customer_details_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Customer Details', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_customer_details_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Customer Details', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_customer_details_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Customer Details', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_customer_details_margin_bottom',
					'std' => '25',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Customer Details', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_customer_details_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Customer Details', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_customer_details_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Customer Details', 'lc-woo-integration' ),
			),

			/**
			 * Customer Details > Table > Cart > Title
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_customer_details_table_cart_title_bg_color',
				'std' => '#f8f8f8',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account table.customer_details tr th',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_customer_details_table_cart_title_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_title_border_color',
					'std' => '#f8f8f8',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr th',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_title_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr th',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_title_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr th',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_title_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr th',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_customer_details_table_cart_title_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_customer_details_table_cart_title_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_title_color',
					'std' => '#43454b',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr th',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_title_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr th',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_title_font_weight',
					'std' => '500',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr th',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_title_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr th',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_title_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr th',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_customer_details_table_cart_title_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_customer_details_table_cart_title_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_title_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr th',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_title_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr th',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_title_padding_bottom',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr th',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_title_padding_left',
					'onlypositive' => true,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr th',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_customer_details_table_cart_title_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Table > Cart > Title', 'lc-woo-integration' ),
			),

			/**
			 * Customer Details > Table > Cart > Item
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_customer_details_table_cart_item_bg_color',
				'std' => '#fdfdfd',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account table.customer_details tr td',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_customer_details_table_cart_item_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_item_border_color',
					'std' => '#fdfdfd',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr td',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_item_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr td',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_item_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr td',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_item_border_trbl',
					'std' => 'bottom',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr td',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_customer_details_table_cart_item_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_customer_details_table_cart_item_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_item_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr td',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_item_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr td',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_item_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr td',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_item_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr td',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_item_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr td',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_customer_details_table_cart_item_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_customer_details_table_cart_item_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_item_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr td',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_item_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr td',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_item_padding_bottom',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr td',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_customer_details_table_cart_item_padding_left',
					'onlypositive' => true,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.customer_details tr td',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_customer_details_table_cart_item_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Table > Cart > Item', 'lc-woo-integration' ),
			),

			/**
			 * Address > Edit
			 */

			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_address_edit_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Address > Edit', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_address_edit_color',
					'std' => '#484c51',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .addresses header a.edit',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Address > Edit', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Color: Hover', 'lc-woo-integration' ),
					'id' => 'css_address_edit_color_hover',
					'std' => '#253d59',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .addresses header a.edit:hover',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Address > Edit', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_address_edit_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .addresses header a.edit',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Address > Edit', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_address_edit_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .addresses header a.edit',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Address > Edit', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_address_edit_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .addresses header a.edit',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Address > Edit', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_address_edit_line_height',
					'std' => '23',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .addresses header a.edit',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Address > Edit', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_address_edit_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Address > Edit', 'lc-woo-integration' ),
			),

			/**
			 * Address > Title
			 */

			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_address_title_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Address > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_address_title_color',
					'std' => '#484c51',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .addresses h3, .lcwoo_account header.title h3',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Address > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_address_title_font_size',
					'std' => '21',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .addresses h3, .lcwoo_account header.title h3',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Address > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_address_title_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .addresses h3, .lcwoo_account header.title h3',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Address > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_address_title_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .addresses h3, .lcwoo_account header.title h3',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Address > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_address_title_line_height',
					'std' => '27',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .addresses h3, .lcwoo_account header.title h3',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Address > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_address_title_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Address > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_address_title_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Address > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_address_title_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .addresses h3, .lcwoo_account header.title h3',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Address > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_address_title_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .addresses h3, .lcwoo_account header.title h3',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Address > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_address_title_margin_bottom',
					'std' => '18',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .addresses h3, .lcwoo_account header.title h3',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Address > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_address_title_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account .addresses h3, .lcwoo_account header.title h3',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Address > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_address_title_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Address > Title', 'lc-woo-integration' ),
			),

			/**
			 * Address > Item
			 */

			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_address_item_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Address > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_address_item_border_color',
					'std' => 'rgba(0,0,0,0)',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account address',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Address > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_address_item_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account address',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Address > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_address_item_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account address',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Address > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_address_item_border_trbl',
					'std' => '',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account address',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Address > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_address_item_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Address > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_address_item_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Address > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_address_item_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account address',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Address > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_address_item_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account address',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Address > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_address_item_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account address',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Address > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Style', 'lc-woo-integration' ),
					'id' => 'css_address_item_font_style',
					'std' => 'italic',
					'type' => 'select',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account address',
					'affect_on_change_rule' => 'font-style',
					'section' => 'styling',
					'tab' => __( 'Address > Item', 'lc-woo-integration' ),
					'choices' => array(
						array(
							'label' => __( 'Normal', 'lc-woo-integration' ),
							'value' => 'normal',
						),
						array(
							'label' => __( 'Italic', 'lc-woo-integration' ),
							'value' => 'italic',
						),
					),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_address_item_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account address',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Address > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_address_item_line_height',
					'std' => '23',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account address',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Address > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_address_item_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Address > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_address_item_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Address > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_address_item_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account address',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Address > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_address_item_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account address',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Address > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_address_item_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account address',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Address > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_address_item_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account address',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Address > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_address_item_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Address > Item', 'lc-woo-integration' ),
			),

			/**
			 * Downloads > Table > Title
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_title_text_align',
				'std' => 'left',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads thead tr th',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_title_bg_color',
				'std' => '#f8f8f8',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads thead tr th',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_title_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_title_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads thead tr th',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_title_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads thead tr th',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_title_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads thead tr th',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_title_border_trbl',
					'std' => 'bottom',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads thead tr th',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_title_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_title_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_title_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads thead tr th',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_title_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads thead tr th',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_title_font_weight',
					'std' => '500',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads thead tr th',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_title_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads thead tr th',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_title_line_height',
					'std' => '21',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads thead tr th',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Text Transform', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_title_text_transform',
					'std' => 'uppercase',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => __( 'None', 'lc-woo-integration' ),
							'value' => 'none',
						),
						array(
							'label' => __( 'Capitalize', 'lc-woo-integration' ),
							'value' => 'capitalize',
						),
						array(
							'label' => __( 'Uppercase', 'lc-woo-integration' ),
							'value' => 'uppercase',
						),
						array(
							'label' => __( 'Lowercase', 'lc-woo-integration' ),
							'value' => 'lowercase',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads thead tr th',
					'affect_on_change_rule' => 'text-transform',
					'section' => 'styling',
					'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_title_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_title_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_title_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads thead tr th',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_title_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads thead tr th',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_title_padding_bottom',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads thead tr th',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_title_padding_left',
					'onlypositive' => true,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads thead tr th',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_title_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Title', 'lc-woo-integration' ),
			),

			/**
			 * Downloads > Table > Item
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_item_text_align',
				'std' => 'left',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_item_bg_color',
				'std' => '#fdfdfd',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_item_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_item_border_color',
					'std' => '#fdfdfd',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_item_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_item_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_item_border_trbl',
					'std' => 'top',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_item_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_item_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_item_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Link - Color', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_item_link_color',
					'std' => '#96588a',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td a',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Link - Color: Hover', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_item_link_color_hover',
					'std' => '#96588a',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td a:hover',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_item_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_item_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Link - Font Weight', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_item_link_font_weight',
					'std' => '500',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td a',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_item_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_item_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Text Transform', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_item_text_transform',
					'std' => 'none',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => __( 'None', 'lc-woo-integration' ),
							'value' => 'none',
						),
						array(
							'label' => __( 'Capitalize', 'lc-woo-integration' ),
							'value' => 'capitalize',
						),
						array(
							'label' => __( 'Uppercase', 'lc-woo-integration' ),
							'value' => 'uppercase',
						),
						array(
							'label' => __( 'Lowercase', 'lc-woo-integration' ),
							'value' => 'lowercase',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td',
					'affect_on_change_rule' => 'text-transform',
					'section' => 'styling',
					'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_item_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_item_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_item_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_item_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_item_padding_bottom',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_item_padding_left',
					'onlypositive' => true,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads tbody tr td',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_item_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Item', 'lc-woo-integration' ),
			),

			/**
			 * Downloads > Table > Button
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_button_bg_color',
				'std' => '#9a4f8c',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads .download-actions a',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color: Hover', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_button_bg_color_hover',
				'std' => '#7d3f71',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads .download-actions a:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_button_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_button_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads .download-actions a',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_button_border_width',
					'std' => '',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads .download-actions a',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_button_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads .download-actions a',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_button_border_trbl',
					'std' => 'top',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads .download-actions a',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_button_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_button_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_button_color',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads .download-actions a',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Color: Hover', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_button_color_hover',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads .download-actions a:hover',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_button_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads .download-actions a',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_button_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads .download-actions a',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_button_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads .download-actions a',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_button_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads .download-actions a',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_button_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads .download-actions a',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads .download-actions a',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_button_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads .download-actions a',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_downloads_table_button_padding_left',
					'onlypositive' => true,
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_account table.woocommerce-MyAccount-downloads .download-actions a',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_downloads_table_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Downloads > Table > Button', 'lc-woo-integration' ),
			),
		);

		$options = array_merge( $options, $this->shared_options( 'animation_options' ) );
		$options = array_merge( $options, $this->presets_options() );

		return apply_filters( 'dslc_module_options', $options, $this->module_id );
	}

	/**
	 * Module HTML output.
	 *
	 * @param  array $options Module options to fill the module template.
	 * @return void
	 */
	function output( $options ) {
	?>
		[lcwoo_module_account_output]<?php echo serialize($options); ?>[/lcwoo_module_account_output]
	<?php
	}

}

/**
 * Module HTML output.
 *
 * @param  array $options Module options to fill the module template.
 */
function lcwoo_module_account_output( $atts, $content = null ) {

	// Uncode module options passed as serialized content.
	$options = unserialize( $content );

	ob_start();

	global $dslc_active;

	if ( isset( $_POST['dslc_post_id'] ) ) {
		$page_id = $_POST['dslc_post_id'];
	} elseif ( isset( $_GET['dslc_post_id'] ) ) {
		$page_id = $_GET['dslc_post_id'];
	} else {
		$page_id = get_the_ID();
	}

	if ( $dslc_active && is_user_logged_in() && current_user_can( DS_LIVE_COMPOSER_CAPABILITY ) ) {
		$dslc_is_admin = true;
	} else {
		$dslc_is_admin = false;
	}

	// Check if Error-Proof mode activated in module options.
	$error_proof_mode = false;
	if ( isset( $options['error_proof_mode'] ) && '' !== $options['error_proof_mode'] ) {
		$error_proof_mode = true;
	}

	// Check if module rendered via ajax call.
	$ajax_module_render = true;
	if ( isset( $options['module_render_nonajax'] ) ) {
		$ajax_module_render = false;
	}

	// Decide if we should render the module or wait for the page refresh.
	$render_code = true;
	if ( $dslc_is_admin && $error_proof_mode && $ajax_module_render ) {
		$render_code = false;
	}

	if ( is_account_page() || wc_get_page_id( 'myaccount' ) == $page_id ) {

		if ( $render_code ) {
			$output = '<div class="lcwoo_account">' . do_shortcode( '[woocommerce_my_account]' ) . '</div>';
		} else {
			$output = '<div class="dslc-notification dslc-green">' . __( 'Please save and update the page to see changes.', 'lc-woo-integration' ) . '</div>';
		}

		echo $output;

	} else {
		if ( $dslc_active ) {
		?>
		<div class="dslc-notification dslc-red">
			<?php esc_html_e( 'This module will be available when you choose the Account page in WooCommerce. ( WooCommerce -> Settings -> Accounts -> My account page )', 'lc-woo-integration' ); ?>
		</div>
	<?php }
	}

	$shortcode_rendered = ob_get_contents();
	ob_end_clean();

	return $shortcode_rendered;
} add_shortcode( 'lcwoo_module_account_output', 'lcwoo_module_account_output' );

/**
 * Register Module
 */
add_action('dslc_hook_register_modules',
	create_function( '', 'return dslc_register_module( "LCWoo_Account" );' )
);
