<?php
/**
 * Module Cart
 *
 * @package Live Composer - WooCommerce integration
 */

// Prevent direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	header( 'HTTP/1.0 403 Forbidden' );
	exit;
}

/**
 * Module Class
 */
class LCWoo_Cart extends DSLC_Module {

	/**
	 * Unique module id
	 *
	 * @var string
	 */
	var $module_id;

	/**
	 * Module label to show in the page builder
	 *
	 * @var string
	 */
	var $module_title;

	/**
	 * Module icon name (FontAwesome)
	 *
	 * @var string
	 */
	var $module_icon;

	/**
	 * Section in the modules panel that includes this module
	 *
	 * @var string
	 */
	var $module_category;

	/**
	 * Exclude from main listing
	 *
	 * @var string
	 */
	var $exclude_from_main_listing;

	/**
	 * Construct
	 */
	function __construct() {

		$this->module_id = 'LCWoo_Cart';
		$this->module_title = __( 'Cart', 'lc-woo-integration' );
		$this->module_icon = 'cart-arrow-down';
		$this->module_category = 'Woo Cart';
		$this->exclude_from_main_listing = true;
	}

	/**
	 * Options
	 */
	function options() {
		$options = array(

			array(
				'label' => __( 'Show On', 'lc-woo-integration' ),
				'id' => 'css_show_on',
				'std' => 'desktop tablet phone',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Desktop', 'lc-woo-integration' ),
						'value' => 'desktop',
					),
					array(
						'label' => __( 'Tablet', 'lc-woo-integration' ),
						'value' => 'tablet',
					),
					array(
						'label' => __( 'Phone', 'lc-woo-integration' ),
						'value' => 'phone',
					),
				),
			),

			/**
			 * General
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_general_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_main_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_general_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_general_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_general_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_main_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_main_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_main_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_main_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_main_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_main_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_main_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_main_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_main_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_main_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_main_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_main_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_main_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
			),

			/**
			 * Table > General
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_table_general_bg_color',
				'std' => '#F3F3F3',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Table > General', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_table_general_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > General', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_table_general_border_color',
					'std' => '#ECECEC',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table tr.cart_item',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Table > General', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_table_general_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table tr.cart_item',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > General', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_table_general_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table tr.cart_item',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Table > General', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_table_general_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > General', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_table_general_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > General', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_table_general_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'form .shop_table',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Table > General', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_table_general_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'form .shop_table',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Table > General', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_table_general_margin_bottom',
					'std' => '50',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'form .shop_table',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Table > General', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_table_general_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'form .shop_table',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Table > General', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_table_general_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > General', 'lc-woo-integration' ),
			),

			/**
			 * Table > Title
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_table_title_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart table thead tr',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Table > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_table_title_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_table_title_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table thead tr',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_table_title_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table thead tr',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_table_title_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table thead tr',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Table > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_table_title_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_table_title_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_table_title_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'th.product-name, th.product-price, th.product-quantity, th.product-subtotal',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_table_title_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'th.product-name, th.product-price, th.product-quantity, th.product-subtotal',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Table > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_table_title_font_weight',
					'std' => '500',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => 'th.product-name, th.product-price, th.product-quantity, th.product-subtotal',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Table > Title', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_table_title_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'th.product-name, th.product-price, th.product-quantity, th.product-subtotal',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_table_title_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'th.product-name, th.product-price, th.product-quantity, th.product-subtotal',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Table > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Text Transform', 'lc-woo-integration' ),
					'id' => 'css_table_title_text_transform',
					'std' => 'uppercase',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => __( 'None', 'lc-woo-integration' ),
							'value' => 'none',
						),
						array(
							'label' => __( 'Capitalize', 'lc-woo-integration' ),
							'value' => 'capitalize',
						),
						array(
							'label' => __( 'Uppercase', 'lc-woo-integration' ),
							'value' => 'uppercase',
						),
						array(
							'label' => __( 'Lowercase', 'lc-woo-integration' ),
							'value' => 'lowercase',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => 'th.product-name, th.product-price, th.product-quantity, th.product-subtotal',
					'affect_on_change_rule' => 'text-transform',
					'section' => 'styling',
					'tab' => __( 'Table > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_table_title_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_title_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_table_title_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table thead tr th',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_table_title_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table thead tr th',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_table_title_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table thead tr th',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_table_title_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table thead tr th',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_title_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Title', 'lc-woo-integration' ),
			),

			/**
			 * Table > Column Width
			 */

			array(
				'label' => __( 'Remove', 'lc-woo-integration' ),
				'id' => 'css_table_column_width_remove',
				'std' => '6',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-remove',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Table > Column Width', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Image', 'lc-woo-integration' ),
				'id' => 'css_table_column_width_thumbnail',
				'std' => '29',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-thumbnail',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Table > Column Width', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Name', 'lc-woo-integration' ),
				'id' => 'css_table_column_width_name',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-name',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Table > Column Width', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Price', 'lc-woo-integration' ),
				'id' => 'css_table_column_width_price',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-price',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Table > Column Width', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Quantity', 'lc-woo-integration' ),
				'id' => 'css_table_column_width_quantity',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-quantity',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Table > Column Width', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Total', 'lc-woo-integration' ),
				'id' => 'css_table_column_width_total',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-subtotal',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Table > Column Width', 'lc-woo-integration' ),
			),

			/**
			 * Table > Remove
			 */

			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_table_button_remove_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.product-remove a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Table > Remove', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_table_button_remove_line_height',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.product-remove a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'tab' => __( 'Table > Remove', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Width', 'lc-woo-integration' ),
				'id' => 'css_table_button_remove_width',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .product-remove a',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'min' => 1,
				'max' => 100,
				'ext' => 'px',
				'tab' => __( 'Table > Remove', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Height', 'lc-woo-integration' ),
				'id' => 'css_table_button_remove_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .product-remove a',
				'affect_on_change_rule' => 'height',
				'section' => 'styling',
				'min' => 1,
				'max' => 100,
				'ext' => 'px',
				'tab' => __( 'Table > Remove', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_button_remove_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Remove', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_table_button_remove_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-remove',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Remove', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_table_button_remove_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-remove',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Remove', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_table_button_remove_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-remove',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Remove', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_table_button_remove_padding_left',
					'onlypositive' => true,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-remove',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Remove', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_button_remove_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Remove', 'lc-woo-integration' ),
			),

			/**
			 * Table > Image
			 */

			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_table_image_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Image', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_table_image_border_color',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-thumbnail a img',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Table > Image', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_table_image_border_width',
					'std' => '4',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-thumbnail a img',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Image', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_table_image_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-thumbnail a img',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Table > Image', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_table_image_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-thumbnail a img',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'tab' => __( 'Table > Image', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_table_image_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Image', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Image - Width', 'lc-woo-integration' ),
				'id' => 'css_table_image_width',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.product-thumbnail a img',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'tab' => __( 'Table > Image', 'lc-woo-integration' ),
				'min' => 1,
				'max' => 100,
				'ext' => '%',
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_image_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Image', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_table_image_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-thumbnail',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Image', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_table_image_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '30',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-thumbnail',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Image', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_table_image_padding_bottom',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-thumbnail',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Image', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_table_image_padding_left',
					'onlypositive' => true,
					'std' => '30',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-thumbnail',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Image', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_image_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Image', 'lc-woo-integration' ),
			),

			/**
			 * Table > Name
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_table_name_text_align',
				'std' => 'left',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Table > Name', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_table_name_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Name', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_table_name_color',
					'std' => '#000000',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name a',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Table > Name', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_table_name_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name a',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Table > Name', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_table_name_font_weight',
					'std' => '500',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name a',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Table > Name', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_table_name_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name a',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Table > Name', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_table_name_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name a',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Table > Name', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Text Transform', 'lc-woo-integration' ),
					'id' => 'css_table_name_text_transform',
					'std' => 'none',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => __( 'None', 'lc-woo-integration' ),
							'value' => 'none',
						),
						array(
							'label' => __( 'Capitalize', 'lc-woo-integration' ),
							'value' => 'capitalize',
						),
						array(
							'label' => __( 'Uppercase', 'lc-woo-integration' ),
							'value' => 'uppercase',
						),
						array(
							'label' => __( 'Lowercase', 'lc-woo-integration' ),
							'value' => 'lowercase',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name',
					'affect_on_change_rule' => 'text-transform',
					'section' => 'styling',
					'tab' => __( 'Table > Name', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_table_name_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Name', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_name_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Name', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_table_name_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-name',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Name', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_table_name_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-name',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Name', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_table_name_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-name',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Name', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_table_name_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-name',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Name', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_name_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Name', 'lc-woo-integration' ),
			),

			/**
			 * Table > Name > Variation
			 */

			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_table_name_variation_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Name > Variation', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color - One', 'lc-woo-integration' ),
					'id' => 'css_table_name_variation_dt_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name dt',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Table > Name > Variation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Color - One', 'lc-woo-integration' ),
					'id' => 'css_table_name_variation_dd_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name dd',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Table > Name > Variation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_table_name_variation_dt_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Table > Name > Variation', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight - One', 'lc-woo-integration' ),
					'id' => 'css_table_name_variation_dd_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name dt',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Table > Name > Variation', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Weight - Two', 'lc-woo-integration' ),
					'id' => 'css_table_name_variation_font_weight',
					'std' => '500',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name dd',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Table > Name > Variation', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_table_name_variation_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Table > Name > Variation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_table_name_variation_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Table > Name > Variation', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_table_name_variation_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Name > Variation', 'lc-woo-integration' ),
			),

			/**
			 * Table > Price
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_table_price_text_align',
				'std' => 'left',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-price',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Table > Price', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_table_price_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Price', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_table_price_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-price',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Table > Price', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_table_price_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-price',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Table > Price', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_table_price_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-price',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Table > Price', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_table_price_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-price',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Table > Price', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_table_price_line_height',
					'std' => '25',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-price',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Table > Price', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_table_price_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Price', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_price_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Price', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_table_price_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-price',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Price', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_table_price_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-price',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Price', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_table_price_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-price',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Price', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_table_price_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-price',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Price', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_price_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Price', 'lc-woo-integration' ),
			),

			/**
			 * Table > Quantity
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_table_quantity_bg_color',
				'std' => '#EFEFEF',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.product-quantity input[type=number]',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_table_quantity_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_table_quantity_border_color',
					'std' => '#DDDDDD',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_table_quantity_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_table_quantity_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_table_quantity_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_table_quantity_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_table_quantity_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_table_quantity_color',
					'std' => '#4D4D4D',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_table_quantity_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_table_quantity_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_table_quantity_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_table_quantity_line_height',
					'std' => '25',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_table_quantity_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding - Quantity', 'lc-woo-integration' ),
				'id' => 'css_table_quantity_quantity_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_table_quantity_quantity_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_table_quantity_quantity_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_table_quantity_quantity_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_table_quantity_quantity_padding_left',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding - Quantity', 'lc-woo-integration' ),
				'id' => 'css_table_quantity_quantity_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Quantity - Width', 'lc-woo-integration' ),
				'id' => 'css_table_quantity_width',
				'std' => '27',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.product-quantity input[type=number]',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
				'ext' => '%',
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_quantity_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_table_quantity_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-quantity',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_table_quantity_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-quantity',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_table_quantity_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-quantity',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_table_quantity_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-quantity',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_quantity_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Quantity', 'lc-woo-integration' ),
			),

			/**
			 * Table > Total
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_table_quantity_text_align',
				'std' => 'left',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-subtotal',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Table > Total', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_table_quantity_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Total', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_table_total_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-subtotal',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Table > Total', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_table_total_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-subtotal',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Table > Total', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_table_total_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-subtotal',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Table > Total', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_table_total_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-subtotal',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Table > Total', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_table_total_line_height',
					'std' => '25',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-subtotal',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Table > Total', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_table_quantity_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Total', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_total_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Total', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_table_total_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-subtotal',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Total', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_table_total_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-subtotal',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Total', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_table_total_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-subtotal',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Total', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_table_total_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-subtotal',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Total', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_total_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Total', 'lc-woo-integration' ),
			),

			/**
			 * Table > Action
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_table_action_bg_color',
				'std' => '#F3F3F3',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .actions',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Table > Action', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_table_action_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Action', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_table_action_border_color',
					'std' => '#DDDDDD',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Table > Action', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_table_action_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Action', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_table_action_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Table > Action', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_table_action_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Action', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_action_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Action', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_table_action_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Action', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_table_action_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Action', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_table_action_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Action', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_table_action_padding_left',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Action', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_action_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Action', 'lc-woo-integration' ),
			),

			/**
			 * Table > Action > Input
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_action_input_bg_color',
				'std' => '#EFEFEF',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_action_input_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_action_input_border_color',
					'std' => '#DDDDDD',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_action_input_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_action_input_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_action_input_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_action_input_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_action_input_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_action_input_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_action_input_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_action_input_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_action_input_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_action_input_line_height',
					'std' => '18',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_action_input_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Width', 'lc-woo-integration' ),
				'id' => 'css_action_input_width',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text], .lcwoo-shopping-cart table.cart td.actions .input-text',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_action_input_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_action_input_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '6',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_action_input_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_action_input_padding_bottom',
					'onlypositive' => true,
					'std' => '6',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_action_input_padding_left',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_action_input_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_action_input_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_action_input_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_action_input_margin_right',
					'std' => '4',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_action_input_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_action_input_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_action_input_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Action > Input', 'lc-woo-integration' ),
			),

			/**
			 * Table > Action > Button
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_table_action_button_bg_color',
				'std' => '#EF510E',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color: Hover', 'lc-woo-integration' ),
				'id' => 'css_table_action_button_bg_hover_color',
				'std' => '#EF510E',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_table_action_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_table_action_button_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_table_action_button_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_table_action_button_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_table_action_button_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_table_action_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_table_action_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_table_action_button_color',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_table_action_button_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_table_action_button_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_table_action_button_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_table_action_button_line_height',
					'std' => '18',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Text Transform', 'lc-woo-integration' ),
					'id' => 'css_table_action_button_text_transform',
					'std' => 'capitalize',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => __( 'None', 'lc-woo-integration' ),
							'value' => 'none',
						),
						array(
							'label' => __( 'Capitalize', 'lc-woo-integration' ),
							'value' => 'capitalize',
						),
						array(
							'label' => __( 'Uppercase', 'lc-woo-integration' ),
							'value' => 'uppercase',
						),
						array(
							'label' => __( 'Lowercase', 'lc-woo-integration' ),
							'value' => 'lowercase',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'text-transform',
					'section' => 'styling',
					'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_table_action_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_action_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_table_action_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_table_action_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_table_action_button_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_table_action_button_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_table_action_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Table > Action > Button', 'lc-woo-integration' ),
			),

			/**
			 * Cross Sells > General
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_general_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > General', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_general_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > General', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_general_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > General', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_general_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > General', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_general_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > General', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_general_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > General', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_general_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > General', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Product - Width', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_general_width',
				'std' => '43',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Cross Sells > General', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Product - Margin', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_general_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > General', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_general_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > General', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_general_margin_right',
					'std' => '30',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > General', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_general_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > General', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_general_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > General', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Product - Margin', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_general_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > General', 'lc-woo-integration' ),
			),

			/**
			 * Cross Sells > Title
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_title_text_align',
				'std' => 'left',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells h2',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_title_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells h2',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_title_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_title_color',
					'std' => '#484C51',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_title_font_size',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_title_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_title_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_title_line_height',
					'std' => '39',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_title_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_title_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_title_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_title_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_title_margin_bottom',
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_title_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_title_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_title_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_title_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_title_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_title_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_title_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_title_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Title', 'lc-woo-integration' ),
			),

			/**
			 * Cross Sells > Product
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_product_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_product_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_product_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_product_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_product_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_product_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_product_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Product', 'lc-woo-integration' ),
			),

			/**
			 * Cross Sells > Image
			 */

			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_image_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_image_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_image_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_image_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_image_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_image_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_image_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_image_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_image_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_image_margin_bottom',
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_image_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_image_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_image_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_image_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_image_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_image_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_image_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_image_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Image', 'lc-woo-integration' ),
			),

			/**
			 * Cross Sells > Product Title
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_product_title_text_align',
				'std' => 'center',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li h2',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Product Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_product_title_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Product Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_title_color',
					'std' => '#484C51',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li h2',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Product Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_title_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li h2',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Product Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_title_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li h2',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Cross Sells > Product Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_title_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li h2',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Product Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_title_line_height',
					'std' => '22',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li h2',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Product Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_product_title_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Product Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_product_title_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Product Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_title_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li h2',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Product Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_title_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li h2',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Product Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_title_margin_bottom',
					'std' => '5',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li h2',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Product Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_product_title_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li h2',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Product Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_product_title_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Product Title', 'lc-woo-integration' ),
			),

			/**
			 * Cross Sells > Price
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_price_text_align',
				'std' => 'center',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li .price',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Price', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_price_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Price', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_price_color_one',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price ins span, .cross-sells ul.products li .price',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Price', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Color - Sale', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_price_color_two',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price del span',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Price', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_price_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Price', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_price_font_weight_one',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price ins span, .cross-sells ul.products li .price',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Cross Sells > Price', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight - Sale', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_price_font_weight_two',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price del span',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Cross Sells > Price', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_price_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Price', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_price_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Price', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_price_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Price', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_price_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Price', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_price_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Price', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_price_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Price', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_price_margin_bottom',
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Price', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_price_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Price', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_price_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Price', 'lc-woo-integration' ),
			),

			/**
			 * Cross Sells > Stars
			 */

			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_stars_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Stars', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_stars_color',
					'std' => '#96588A',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Stars', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_stars_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Stars', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_stars_line_height',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Stars', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_stars_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Stars', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_stars_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Stars', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_stars_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Stars', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_stars_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Stars', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_stars_margin_bottom',
					'std' => '5',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Stars', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_stars_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Stars', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_stars_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Stars', 'lc-woo-integration' ),
			),

			/**
			 * Cross Sells > Button
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_button_text_align',
				'std' => 'center',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_button_bg_color',
				'std' => '#EF510E',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li .button',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color: Hover', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_button_hover_bg_color',
				'std' => '#E19879',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li .button:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_button_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_button_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_button_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_button_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_button_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_button_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_button_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_button_color',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_button_form_font_size',
					'std' => '16',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'ul.products li .button',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_button_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_button_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_button_line_height',
					'std' => '22',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_button_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_button_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_button_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_button_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_button_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_button_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_button_margin_bottom',
					'std' => '30',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_button_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_button_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Button', 'lc-woo-integration' ),
			),

			/**
			 * Cross Sells > Sale
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_sale_bg_color',
				'std' => '#77a464',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_sale_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_sale_border_color',
					'std' => '#77a464',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_sale_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_sale_border_radius',
					'std' => '44',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_sale_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_sale_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_sale_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_sale_form_color',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_sale_form_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_sale_form_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_sale_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_sale_line_height',
					'std' => '34',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Text Transform', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_sale_text_transform',
					'std' => 'uppercase',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => __( 'None', 'lc-woo-integration' ),
							'value' => 'none',
						),
						array(
							'label' => __( 'Capitalize', 'lc-woo-integration' ),
							'value' => 'capitalize',
						),
						array(
							'label' => __( 'Uppercase', 'lc-woo-integration' ),
							'value' => 'uppercase',
						),
						array(
							'label' => __( 'Lowercase', 'lc-woo-integration' ),
							'value' => 'lowercase',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'text-transform',
					'section' => 'styling',
					'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_sale_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_sale_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_sale_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_sale_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_sale_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_cross_sells_sale_padding_left',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_sale_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Top', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_sale_margin_top',
				'std' => '-6',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
				'affect_on_change_rule' => 'margin-top',
				'section' => 'styling',
				'min' => -100,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Right', 'lc-woo-integration' ),
				'id' => 'css_cross_sells_sale_margin_right',
				'std' => '-3',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
				'affect_on_change_rule' => 'margin-right',
				'section' => 'styling',
				'min' => -100,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Cross Sells > Sale', 'lc-woo-integration' ),
			),

			/**
			 * Cart Totals > General
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_totals',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > General', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > General', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > General', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > General', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > General', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > General', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > General', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table - Width', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_table_width',
				'std' => '100',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-collaterals table.shop_table',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'visibility' => 'hidden',
				'tab' => __( 'Cart Totals > General', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table Th - Width', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_table_th_width',
				'std' => '35',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-collaterals table.shop_table th',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Cart Totals > General', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table Td - Width', 'lc-woo-integration' ),
				'id' => 'css_cart_totals__table_td_width',
				'std' => '65',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-collaterals table.shop_table td',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Cart Totals > General', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > General', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals table',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > General', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals table',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > General', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_margin_bottom',
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals table',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > General', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals table',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > General', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > General', 'lc-woo-integration' ),
			),

			/**
			 * Cart Totals > Title
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_title_text_align',
				'std' => 'left',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_totals h2',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_title_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_totals h2',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_title_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_title_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_title_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_title_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_title_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_title_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_title_color',
					'std' => '#484C51',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_title_font_size',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_title_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_title_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_title_line_height',
					'std' => '39',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_title_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_title_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_title_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_title_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_title_margin_bottom',
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_title_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_title_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_title_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_title_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_title_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_title_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_title_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_title_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Title', 'lc-woo-integration' ),
			),

			/**
			 * Cart Totals > Cart Title
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_cart_title_text_align',
				'std' => 'left',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_cart_title_bg_color',
				'std' => '#f8f8f8',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_cart_title_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_title_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cart_totals tr th',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_title_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cart_totals tr th',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_title_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cart_totals tr th',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_cart_title_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_cart_title_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_title_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_title_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_title_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_title_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_title_line_height',
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_cart_title_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_cart_title_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_title_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_title_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '30',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_title_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_title_padding_left',
					'onlypositive' => true,
					'std' => '30',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_cart_title_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Cart Title', 'lc-woo-integration' ),
			),

			/**
			 * Cart Totals > Cart Item
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_cart_item_bg_color',
				'std' => '#fdfdfd',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-subtotal td, .order-total td',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_cart_item_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_item_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cart_totals tr td',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_item_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cart_totals tr td',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_item_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cart_totals tr td',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_cart_item_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_cart_item_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_item_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_item_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_item_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_item_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_item_line_height',
					'std' => '25',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				/*array(
					'label' => __( 'Text Align', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_item_text_align',
					'std' => 'left',
					'type' => 'text_align',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'text-align',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
				),*/ // WooCommerce have !important
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_cart_item_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_cart_item_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_item_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_item_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '27',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_item_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_cart_item_padding_left',
					'onlypositive' => true,
					'std' => '27',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_cart_item_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Cart Item', 'lc-woo-integration' ),
			),

			/**
			 * Shipping
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.shipping td',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Shipping', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Shipping', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Shipping', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Color - Link', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_link_color',
					'std' => '#000000',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td a.shipping-calculator-button, .shipping td a.show_hide',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Shipping', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Color: Hover - Link', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_link_color_hover',
					'std' => '#000000',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td a.shipping-calculator-button:hover, .shipping td a.show_hide:hover',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Shipping', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Shipping', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Shipping', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Weight - Link', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_link_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td a.shipping-calculator-button, .shipping td a.show_hide',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Shipping', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Shipping', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_line_height',
					'std' => '25',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Shipping', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Shipping', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Shipping', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Shipping', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '27',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Shipping', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Shipping', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_padding_left',
					'onlypositive' => true,
					'std' => '27',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Shipping', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Shipping', 'lc-woo-integration' ),
			),

			/**
			 * Shipping > Select
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_select_bg_color',
				'std' => '#FFFFFF',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-shipping-calculator select',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_select_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_select_border_color',
					'std' => '#E8E8E8',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator select',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_select_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator select',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_select_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator select',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_select_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_select_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_select_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator select',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_select_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator select',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_select_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator select',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_select_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator select',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_select_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_select_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_select_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_country_field',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_select_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_country_field',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_select_margin_bottom',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_country_field',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_select_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_country_field',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_select_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Shipping > Select', 'lc-woo-integration' ),
			),

			/**
			 * Shipping > Input
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_input_bg_color',
				'std' => '#EFEFEF',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-shipping-calculator input',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_input_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_input_border_color',
					'std' => '#E8E8E8',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_input_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_input_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_input_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_input_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_input_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_input_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_input_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_input_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_input_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_input_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_input_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_input_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_input_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_state_field, .woocommerce-shipping-calculator p#calc_shipping_postcode_field',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_input_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_state_field, .woocommerce-shipping-calculator p#calc_shipping_postcode_field',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_input_margin_bottom',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_state_field, .woocommerce-shipping-calculator p#calc_shipping_postcode_field',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_input_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_state_field, .woocommerce-shipping-calculator p#calc_shipping_postcode_field',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_input_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_input_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_input_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_input_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_input_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_input_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_input_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Shipping > Input', 'lc-woo-integration' ),
			),

			/**
			 * Shipping > Button
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_button_bg_color',
				'std' => '#EF510E',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-shipping-calculator button',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color: Hover', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_button_hover_bg_color',
				'std' => '#EF510E',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-shipping-calculator button:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_button_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_button_border_color',
					'std' => '#E8E8E8',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_button_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_button_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_button_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_button_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_button_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_button_color',
					'std' => '#FFFFFF',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_button_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_button_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_button_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_button_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_button_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_button_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_button_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_button_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_button_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_button_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_button_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_button_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_cart_shipping_button_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cart_shipping_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Shipping > Button', 'lc-woo-integration' ),
			),

			/**
			 * Cart Totals > Button
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_button_text_align',
				'std' => 'center',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.wc-proceed-to-checkout a',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_button_bg_color',
				'std' => '#000000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.wc-proceed-to-checkout a',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color: Hover', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_button_hover_bg_color',
				'std' => '#000000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.wc-proceed-to-checkout a:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_button_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_button_border_color',
					'std' => '#e8e8e8',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_button_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_button_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_button_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_button_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_button_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_button_color',
					'std' => '#FFFFFF',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_button_form_font_size',
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_button_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_button_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_button_line_height',
					'std' => '34',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_button_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Width', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_button_width',
				'std' => '100',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.wc-proceed-to-checkout a',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
				'min' => 1,
				'max' => 100,
				'ext' => '%',
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_button_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_button_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_button_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_button_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_button_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_button_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_button_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_cart_totals_button_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cart_totals_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Totals > Button', 'lc-woo-integration' ),
			),

			/**
			 * Cart Empty
			 */

			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_empty_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Empty', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_color',
					'std' => '#43454b',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Cart Empty', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_form_font_size',
					'std' => '16',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Empty', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Cart Empty', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Cart Empty', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_line_height',
					'std' => '18',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Empty', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_empty_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Empty', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cart_empty_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Empty', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Cart Empty', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Cart Empty', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_margin_bottom',
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Cart Empty', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Cart Empty', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cart_empty_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Empty', 'lc-woo-integration' ),
			),

			/**
			 * Cart Empty > Button
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_cart_empty_button_bg_color',
				'std' => '#EF510E',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color: Hover', 'lc-woo-integration' ),
				'id' => 'css_cart_empty_button_hover_bg_color',
				'std' => '#EF510E',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_empty_button_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_button_border_color',
					'std' => '#e8e8e8',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_button_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_button_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_button_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_cart_empty_button_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_empty_button_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_button_color',
					'std' => '#FFFFFF',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_button_form_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_button_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_button_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_button_line_height',
					'std' => '18',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_cart_empty_button_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cart_empty_button_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_button_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_button_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_button_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_button_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_cart_empty_button_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cart_empty_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_button_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_cart_empty_button_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_cart_empty_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Cart Empty > Button', 'lc-woo-integration' ),
			),

			/**
			 * Notice - Coupon
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_notice_coupon_bg_color',
				'std' => '#3D9CD2',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_notice_coupon_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Coupon', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_notice_coupon_border_color',
					'std' => 'rgba(0,0,0, 0.15)',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Coupon', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_notice_coupon_border_width',
					'std' => '9',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Coupon', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_notice_coupon_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Coupon', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_notice_coupon_border_trbl',
					'std' => 'left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Coupon', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_notice_coupon_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_notice_coupon_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Coupon', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_notice_coupon_color',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error li',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Coupon', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_notice_coupon_font_size',
					'std' => '16',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error li',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Coupon', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_notice_coupon_font_weight',
					'std' => '200',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error li',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Coupon', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_notice_coupon_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error li',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Coupon', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_notice_coupon_line_height',
					'std' => '34',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error li',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Coupon', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_notice_coupon_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Coupon', 'lc-woo-integration' ),
			),

			/**
			 * Notice
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_notice_bg_color',
				'std' => '#0f834d',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-message',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Notice', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_notice_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Notice', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_notice_border_color',
					'std' => '#0c6f41',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_notice_border_width',
					'std' => '9',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_notice_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_notice_border_trbl',
					'std' => 'left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_notice_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Notice', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_notice_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Notice', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_notice_color',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_notice_font_size',
					'std' => '16',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_notice_font_weight',
					'std' => '200',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_notice_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_notice_line_height',
					'std' => '34',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_notice_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Notice', 'lc-woo-integration' ),
			),

			/**
			 * Notice > Button
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_notice_button_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-message a',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color: Hover', 'lc-woo-integration' ),
				'id' => 'css_notice_button_hover_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-message a:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_notice_button_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_notice_button_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_notice_button_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_notice_button_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_notice_button_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_notice_button_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_notice_button_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_notice_button_color',
					'std' => '#FFFFFF',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_notice_button_form_font_size',
					'std' => '16',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_notice_button_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_notice_button_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_notice_button_line_height',
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_notice_button_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_notice_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_notice_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_notice_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_notice_button_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_notice_button_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_notice_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_notice_button_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_notice_button_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_notice_button_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_notice_button_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_notice_button_margin_left',
					'std' => '5',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_notice_button_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Notice > Button', 'lc-woo-integration' ),
			),

			/**
			 * Responsive Tablet
			 */

			array(
				'label' => __( 'Responsive Styling', 'lc-woo-integration' ),
				'id' => 'css_res_t',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_main_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_main_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_main_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_main_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'form .shop_table',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'form .shop_table',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_margin_bottom',
					'std' => '30',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'form .shop_table',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'form .shop_table',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Table - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Table > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_title_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'th.product-name, th.product-price, th.product-quantity, th.product-subtotal',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Table > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_title_line_height',
				'std' => '23',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'th.product-name, th.product-price, th.product-quantity, th.product-subtotal',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Remove - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_button_remove_font_size',
				'std' => '13',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.product-remove a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Remove - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_button_remove_line_height',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.product-remove a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Remove - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_button_remove_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_button_remove_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-remove',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_button_remove_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-remove',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_button_remove_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-remove',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_button_remove_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-remove',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Remove - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_button_remove_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Remove - Width', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_button_remove_width',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .product-remove a',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'min' => 1,
				'max' => 100,
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Remove - Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_button_remove_height',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .product-remove a',
				'affect_on_change_rule' => 'height',
				'section' => 'responsive',
				'min' => 1,
				'max' => 100,
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Image - Width', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_image_width',
				'std' => '75',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.product-thumbnail a img',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'min' => 1,
				'max' => 100,
				'ext' => '%',
			),
			array(
				'label' => __( 'Table > Td Image - Width', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_td_image_width',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-thumbnail',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Image - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_image_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_image_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-thumbnail',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_image_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-thumbnail',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_image_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-thumbnail',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_image_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-thumbnail',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Image - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_image_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Name - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_name_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Name - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_name_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Name - Width', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_name_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-name',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Name - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_name_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_name_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-name',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_name_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-name',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_name_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-name',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_name_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-name',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Name - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_name_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Name > Variation - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_name_variation_dt_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Name > Variation - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_name_variation_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Price - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_price_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-price',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Price - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_price_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-price',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Price - Width', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_price_width',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-price',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Price - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_price_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_price_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-price',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_price_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-price',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_price_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-price',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_price_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-price',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Price - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_price_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Quantity - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_quantity_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.product-quantity input[type=number]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Quantity - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_quantity_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.product-quantity input[type=number]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Quantity - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_quantity_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_quantity_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_quantity_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_quantity_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_quantity_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Quantity - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_quantity_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Quantity - Width', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_quantity_width',
				'std' => '45',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.product-quantity input[type=number]',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => '%',
			),
			array(
				'label' => __( 'Table > Quantity Td - Width', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_quantity_td_width',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-quantity',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Quantity Td - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_quantity_td_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_quantity_td_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-quantity',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_quantity_td_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-quantity',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_quantity_td_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-quantity',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_quantity_td_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-quantity',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Quantity Td - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_quantity_td_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Total - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_total_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-subtotal',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Total - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_total_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-subtotal',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Total - Width', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_total_width',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-subtotal',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Total - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_total_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_total_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-subtotal',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_total_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-subtotal',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_total_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-subtotal',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_total_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-subtotal',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Total - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_total_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Action - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_action_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_action_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_action_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_action_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_action_padding_left',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Action - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_action_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Action > Input - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_action_input_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Action > Input - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_action_input_line_height',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Action > Input - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_action_input_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_action_input_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_action_input_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_action_input_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_action_input_padding_left',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Action > Input - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_action_input_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Action > Input - Width', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_action_input_width',
				'std' => '50',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text], .lcwoo-shopping-cart table.cart td.actions .input-text',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Action > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_action_button_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Action > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_action_button_line_height',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Action > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_action_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_action_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_action_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_action_button_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_table_action_button_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Action > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_table_action_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cross-sells',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cross-sells',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cross-sells',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cross-sells',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cross Sells - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_margin_bottom',
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cross Sells - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_title_font_size',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells h2',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cross Sells > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_title_line_height',
				'std' => '39',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells h2',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cross Sells > Title - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_title_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_title_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_title_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_title_margin_bottom',
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_title_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cross Sells > Title - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_title_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Title - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_title_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_title_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_title_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_title_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_title_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cross Sells > Title - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_title_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Product - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_product_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_product_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_product_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_product_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_product_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cross Sells > Product - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_product_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Product - Width', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_product_width',
				'std' => '45',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'min' => 1,
				'max' => 100,
				'ext' => '%',
			),
			array(
				'label' => __( 'Cross Sells > Product - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_product_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_product_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_product_margin_right',
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_product_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_product_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cross Sells > Product - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_product_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Image - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_image_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_image_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_image_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_image_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_image_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cross Sells > Image - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_image_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Image - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_image_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_image_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_image_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_image_margin_bottom',
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_image_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cross Sells > Image - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_image_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Product Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_product_title_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li h2',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cross Sells > Product Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_product_title_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li h2',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cross Sells > Product Title - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_product_title_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_product_title_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li h2',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_product_title_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li h2',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_product_title_margin_bottom',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li h2',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_product_title_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li h2',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cross Sells > Product Title - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_product_title_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Price - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_price_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li .price',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cross Sells > Price - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_price_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li .price',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cross Sells > Price - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_price_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_price_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_price_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_price_margin_bottom',
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_price_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cross Sells > Price - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_price_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Stars - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_stars_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cross Sells > Stars - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_stars_line_height',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cross Sells > Stars - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_stars_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_stars_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_stars_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_stars_margin_bottom',
					'std' => '5',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_stars_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cross Sells > Stars - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_stars_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_button_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'ul.products li .button',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_button_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li .button',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_button_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_button_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cross Sells > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Sale - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_sale_font_size',
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Sale - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_sale_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Sale - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_sale_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_sale_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '9',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_sale_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '6',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_sale_padding_bottom',
					'onlypositive' => true,
					'std' => '9',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cross_sells_sale_padding_left',
					'onlypositive' => true,
					'std' => '6',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cross Sells > Sale - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_sale_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Sale - Margin Top', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_sale_margin_top',
				'std' => '-6',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
				'affect_on_change_rule' => 'margin-top',
				'section' => 'responsive',
				'min' => -100,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Sale - Margin Right', 'lc-woo-integration' ),
				'id' => 'css_res_t_cross_sells_sale_margin_right',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
				'affect_on_change_rule' => 'margin-right',
				'section' => 'responsive',
				'min' => -100,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals table',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals table',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_margin_bottom',
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals table',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals table',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cart Totals - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Table Th - Width', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_table_th_width',
				'std' => '35',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-collaterals table.shop_table th',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Table Td - Width', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals__table_td_width',
				'std' => '65',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-collaterals table.shop_table td',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_totals_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_totals_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cart_totals',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_totals_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cart_totals',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_totals_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cart_totals',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_totals_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cart_totals',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cart Totals - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_totals_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_totals_title_font_size',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_totals h2',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cart Totals > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_title_line_height',
				'std' => '39',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_totals h2',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cart Totals > Title - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_title_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_title_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_title_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_title_margin_bottom',
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_title_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cart Totals > Title - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_title_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Title - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_title_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_title_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_title_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_title_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_title_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cart Totals > Title - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_title_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Cart Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_cart_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cart Totals > Cart Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_cart_title_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cart Totals > Cart Title - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_main_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_padding_left',
					'onlypositive' => true,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cart Totals > Cart Title - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_main_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Cart Item - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_cart_item_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-subtotal td, .order-total td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cart Totals > Cart Item - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_cart_item_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-subtotal td, .order-total td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cart Totals > Cart Item - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_cart_item_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_cart_item_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_cart_item_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_cart_item_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_cart_item_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cart Totals > Cart Item - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_cart_item_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Shipping - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.shipping td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Shipping - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.shipping td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Shipping - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '27',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_padding_left',
					'onlypositive' => true,
					'std' => '27',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Shipping - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Shipping > Select - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_select_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-shipping-calculator select',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Shipping > Select - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_select_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_select_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_country_field',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_select_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_country_field',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_select_margin_bottom',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_country_field',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_select_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_country_field',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Shipping > Select - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_select_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Shipping > Input - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_input_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-shipping-calculator input',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Shipping > Input - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_input_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-shipping-calculator input',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Shipping > Input - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_input_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_input_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_state_field, .woocommerce-shipping-calculator p#calc_shipping_postcode_field',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_input_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_state_field, .woocommerce-shipping-calculator p#calc_shipping_postcode_field',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_input_margin_bottom',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_state_field, .woocommerce-shipping-calculator p#calc_shipping_postcode_field',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_input_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_state_field, .woocommerce-shipping-calculator p#calc_shipping_postcode_field',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Shipping > Input - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_input_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Shipping > Input - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_input_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_input_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_input_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_input_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_input_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Shipping > Input - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_input_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Shipping > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_button_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-shipping-calculator button',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Shipping > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_button_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-shipping-calculator button',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Shipping > Button - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_button_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_button_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_button_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_button_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_button_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Shipping > Button - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_button_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Shipping > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_button_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_shipping_button_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Shipping > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_shipping_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_button_font_size',
				'std' => '19',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.wc-proceed-to-checkout a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_button_line_height',
				'std' => '33',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.wc-proceed-to-checkout a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_button_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_totals_button_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cart Totals > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_totals_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Empty - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_empty_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Empty - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_empty_line_height',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Empty - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_empty_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_empty_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_empty_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_empty_margin_bottom',
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_empty_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cart Empty - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_empty_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Empty > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_empty_button_form_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Empty > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_empty_button_line_height',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Empty > Button - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_empty_button_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_empty_button_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_empty_button_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_empty_button_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_empty_button_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cart Empty > Button - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_empty_button_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Empty > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_empty_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_empty_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_empty_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_empty_button_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_cart_empty_button_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cart Empty > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_cart_empty_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Notice - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_notice_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-message',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Notice - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_notice_line_height',
				'std' => '34',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-message',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Notice > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_notice_button_form_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-message a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Notice > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_notice_button_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-message a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Notice > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_notice_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_notice_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_notice_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_notice_button_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_notice_button_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Notice > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_notice_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Notice > Button - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_notice_button_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_notice_button_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_notice_button_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_notice_button_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_notice_button_margin_left',
					'std' => '5',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Notice > Button - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_t_notice_button_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),

			/**
			 * Responsive Phone
			 */

			array(
				'label' => __( 'Responsive Styling', 'lc-woo-integration' ),
				'id' => 'css_res_p',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_main_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_main_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_main_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_main_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'form .shop_table',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'form .shop_table',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_margin_bottom',
					'std' => '30',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'form .shop_table',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'form .shop_table',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Table - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table Td - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_td_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_td_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table td',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_td_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table td',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_td_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table td',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_td_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table td',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table Td - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_td_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Table > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_title_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'th.product-name, th.product-price, th.product-quantity, th.product-subtotal',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Table > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_title_line_height',
				'std' => '23',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'th.product-name, th.product-price, th.product-quantity, th.product-subtotal',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Remove - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_button_remove_font_size',
				'std' => '13',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.product-remove a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Remove - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_button_remove_line_height',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.product-remove a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Remove - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_button_remove_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_button_remove_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-remove',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_button_remove_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-remove',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_button_remove_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-remove',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_button_remove_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-remove',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Remove - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_button_remove_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Remove - Width', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_button_remove_width',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .product-remove a',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'min' => 1,
				'max' => 100,
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Remove - Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_button_remove_height',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .product-remove a',
				'affect_on_change_rule' => 'height',
				'section' => 'responsive',
				'min' => 1,
				'max' => 100,
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Image - Width', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_image_width',
				'std' => '50',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.product-thumbnail a img',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'min' => 1,
				'max' => 100,
				'ext' => '%',
			),
			array(
				'label' => __( 'Table > Image - Padding Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_image_padding_bottom',
				'onlypositive' => true,
				'std' => '7',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-thumbnail',
				'affect_on_change_rule' => 'padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Name - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_name_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Name - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_name_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Name - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_name_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_name_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-name',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_name_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-name',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_name_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-name',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_name_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-name',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Name - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_name_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Name > Variation - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_name_variation_dt_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Name > Variation - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_name_variation_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Price - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_price_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-price',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Price - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_price_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-price',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Price - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_price_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_price_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-price',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_price_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-price',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_price_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-price',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_price_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-price',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Price - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_price_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Quantity - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_quantity_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.product-quantity input[type=number]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Quantity - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_quantity_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.product-quantity input[type=number]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Quantity - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_quantity_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_quantity_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_quantity_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_quantity_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_quantity_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.product-quantity input[type=number]',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Quantity - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_quantity_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Quantity Td - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_quantity_td_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_quantity_td_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-quantity',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_quantity_td_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-quantity',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_quantity_td_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-quantity',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_quantity_td_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-quantity',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Quantity Td - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_quantity_td_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Total - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_total_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-subtotal',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Total - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_total_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-subtotal',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Total - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_total_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_total_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-subtotal',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_total_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-subtotal',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_total_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-subtotal',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_total_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart table .cart_item td.product-subtotal',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Total - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_total_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Action - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_action_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_action_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_action_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_action_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_action_padding_left',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Action - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_action_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Action > Input - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_action_input_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Action > Input - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_action_input_line_height',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Action > Input - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_action_input_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_action_input_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_action_input_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_action_input_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_action_input_padding_left',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Action > Input - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_action_input_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Action > Input - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_action_input_margin_bottom',
				'onlypositive' => true,
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=text]',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Action > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_action_button_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Action > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_action_button_line_height',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Table > Action > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_action_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_action_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_action_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_action_button_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_table_action_button_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Table > Action > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_action_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Table > Action > Button - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_table_action_buton_margin_bottom',
				'onlypositive' => true,
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .actions input[type=submit]',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cross-sells',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cross-sells',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cross-sells',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cross-sells',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cross Sells - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_margin_bottom',
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cross Sells - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_title_font_size',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells h2',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cross Sells > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_title_line_height',
				'std' => '39',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells h2',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cross Sells > Title - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_title_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_title_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_title_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_title_margin_bottom',
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_title_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cross Sells > Title - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_title_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Title - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_title_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_title_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_title_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_title_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_title_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells h2',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cross Sells > Title - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_title_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Product - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_product_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_product_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_product_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_product_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_product_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cross Sells > Product - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_product_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Product - Width', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_product_width',
				'std' => '45',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'min' => 1,
				'max' => 100,
				'ext' => '%',
			),
			array(
				'label' => __( 'Cross Sells > Product - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_product_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_product_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_product_margin_right',
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_product_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_product_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cross Sells > Product - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_product_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Image - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_image_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_image_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_image_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_image_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_image_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cross Sells > Image - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_image_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Image - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_image_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_image_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_image_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_image_margin_bottom',
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_image_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li a img',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cross Sells > Image - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_image_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Product Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_product_title_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li h2',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cross Sells > Product Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_product_title_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li h2',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cross Sells > Product Title - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_product_title_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_product_title_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li h2',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_product_title_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li h2',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_product_title_margin_bottom',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li h2',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_product_title_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li h2',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cross Sells > Product Title - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_product_title_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Price - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_price_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li .price',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cross Sells > Price - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_price_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li .price',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cross Sells > Price - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_price_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_price_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_price_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_price_margin_bottom',
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_price_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .price',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cross Sells > Price - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_price_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Stars - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_stars_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cross Sells > Stars - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_stars_line_height',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cross Sells > Stars - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_stars_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_stars_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_stars_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_stars_margin_bottom',
					'std' => '5',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_stars_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .star-rating',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cross Sells > Stars - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_stars_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_button_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'ul.products li .button',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_button_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li .button',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_button_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_button_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li .button',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cross Sells > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Sale - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_sale_font_size',
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Sale - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_sale_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Sale - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_sale_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_sale_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '9',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_sale_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '6',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_sale_padding_bottom',
					'onlypositive' => true,
					'std' => '9',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cross_sells_sale_padding_left',
					'onlypositive' => true,
					'std' => '6',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cross Sells > Sale - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_sale_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Sale - Margin Top', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_sale_margin_top',
				'std' => '-6',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
				'affect_on_change_rule' => 'margin-top',
				'section' => 'responsive',
				'min' => -100,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cross Sells > Sale - Margin Right', 'lc-woo-integration' ),
				'id' => 'css_res_p_cross_sells_sale_margin_right',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cross-sells ul.products li span.onsale',
				'affect_on_change_rule' => 'margin-right',
				'section' => 'responsive',
				'min' => -100,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals table',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals table',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_margin_bottom',
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals table',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals table',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cart Totals - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Table Th - Width', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_table_th_width',
				'std' => '35',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-collaterals table.shop_table th',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Table Td - Width', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals__table_td_width',
				'std' => '65',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-collaterals table.shop_table td',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_totals_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_totals_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cart_totals',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_totals_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cart_totals',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_totals_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cart_totals',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_totals_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-collaterals .cart_totals',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cart Totals - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_totals_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_totals_title_font_size',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_totals h2',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cart Totals > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_title_line_height',
				'std' => '39',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_totals h2',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cart Totals > Title - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_title_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_title_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_title_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_title_margin_bottom',
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_title_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cart Totals > Title - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_title_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Title - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_title_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_title_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_title_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_title_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_title_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_totals h2',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cart Totals > Title - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_title_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Cart Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_cart_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cart Totals > Cart Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_cart_title_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cart Totals > Cart Title - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_main_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_padding_left',
					'onlypositive' => true,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal th, .order-total th, .shipping th',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cart Totals > Cart Title - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_main_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Cart Item - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_cart_item_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-subtotal td, .order-total td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cart Totals > Cart Item - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_cart_item_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart-subtotal td, .order-total td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cart Totals > Cart Item - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_cart_item_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_cart_item_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_cart_item_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_cart_item_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_cart_item_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart-subtotal td, .order-total td',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cart Totals > Cart Item - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_cart_item_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Shipping - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.shipping td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Shipping - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_line_height',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.shipping td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Shipping - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '27',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_padding_left',
					'onlypositive' => true,
					'std' => '27',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.shipping td',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Shipping - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Shipping > Select - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_select_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-shipping-calculator select',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Shipping > Select - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_select_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_select_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_country_field',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_select_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_country_field',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_select_margin_bottom',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_country_field',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_select_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_country_field',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Shipping > Select - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_select_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Shipping > Input - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_input_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-shipping-calculator input',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Shipping > Input - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_input_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-shipping-calculator input',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Shipping > Input - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_input_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_input_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_state_field, .woocommerce-shipping-calculator p#calc_shipping_postcode_field',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_input_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_state_field, .woocommerce-shipping-calculator p#calc_shipping_postcode_field',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_input_margin_bottom',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_state_field, .woocommerce-shipping-calculator p#calc_shipping_postcode_field',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_input_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator p#calc_shipping_state_field, .woocommerce-shipping-calculator p#calc_shipping_postcode_field',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Shipping > Input - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_input_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Shipping > Input - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_input_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_input_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_input_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_input_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_input_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator input',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Shipping > Input - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_input_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Shipping > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_button_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-shipping-calculator button',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Shipping > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_button_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-shipping-calculator button',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Shipping > Button - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_button_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_button_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_button_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_button_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_button_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Shipping > Button - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_button_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Shipping > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_button_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_shipping_button_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-shipping-calculator button',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Shipping > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_shipping_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_button_font_size',
				'std' => '19',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.wc-proceed-to-checkout a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_button_line_height',
				'std' => '33',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.wc-proceed-to-checkout a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Totals > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_button_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_totals_button_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.wc-proceed-to-checkout a',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cart Totals > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_totals_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Empty - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_empty_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Empty - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_empty_line_height',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Empty - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_empty_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_empty_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_empty_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_empty_margin_bottom',
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_empty_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .cart-empty',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cart Empty - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_empty_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Empty > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_empty_button_form_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Empty > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_empty_button_line_height',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Empty > Button - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_empty_button_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_empty_button_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_empty_button_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_empty_button_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_empty_button_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Cart Empty > Button - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_empty_button_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Empty > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_empty_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_empty_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_empty_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_empty_button_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_cart_empty_button_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-shopping-cart .woocommerce .return-to-shop a',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Cart Empty > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_cart_empty_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Notice - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_notice_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-message',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Notice - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_notice_line_height',
				'std' => '34',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-message',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Notice > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_notice_button_form_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-message a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Notice > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_notice_button_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-message a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Notice > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_notice_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_notice_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_notice_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_notice_button_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_notice_button_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-message a',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Notice > Button - Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_notice_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Notice > Button - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_notice_button_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_notice_button_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_notice_button_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_notice_button_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_notice_button_margin_left',
					'std' => '5',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'responsive',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Notice > Button - Margin', 'lc-woo-integration' ),
				'id' => 'css_res_p_notice_button_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
		);

		$options = array_merge( $options, $this->shared_options( 'animation_options' ) );
		$options = array_merge( $options, $this->presets_options() );

		return apply_filters( 'dslc_module_options', $options, $this->module_id );
	}

	/**
	 * Module HTML output.
	 *
	 * @param  array $options Module options to fill the module template.
	 * @return void
	 */
	function output( $options ) {
	?>
		[lcwoo_module_cart_output]<?php echo serialize($options); ?>[/lcwoo_module_cart_output]
	<?php
	}
}

function lcwoo_module_cart_output( $atts, $content = null ) {

	// Uncode module options passed as serialized content.
	$options = unserialize( $content );

	ob_start();

	global $dslc_active;

	if ( isset( $_POST['dslc_post_id'] ) ) {
		$page_id = $_POST['dslc_post_id'];
	} elseif ( isset( $_GET['dslc_post_id'] ) ) {
		$page_id = $_GET['dslc_post_id'];
	} else {
		$page_id = get_the_ID();
	}

	if ( is_cart() || wc_get_page_id( 'cart' ) == $page_id ) { ?>
		<div class='lcwoo-shopping-cart'>
			<?php if ( $dslc_active && ! WC()->cart->is_empty() ) { ?>
				<ul class="woocommerce-error">
					<li>Please enter a coupon code.</li>
				</ul>
				<div class="woocommerce-message">Product removed. <a href="#">Undo?</a></div>
			<?php } ?>
			<?php echo do_shortcode( '[woocommerce_cart]' ); ?>
		</div>
	<?php } else {
		if ( $dslc_active ) {
		?>
		<div class="dslc-notification dslc-red">
			<?php esc_html_e( 'This module will be available when you choose the Cart page in WooCommerce. ( WooCommerce -> Settings -> Checkout -> Cart Page )', 'lc-woo-integration' ); ?>
		</div>
	<?php }
	}

	$shortcode_rendered = ob_get_contents();
	ob_end_clean();

	return $shortcode_rendered;
} add_shortcode( 'lcwoo_module_cart_output', 'lcwoo_module_cart_output' );

/**
 * Register Module
 */
add_action('dslc_hook_register_modules',
	create_function( '', 'return dslc_register_module( "LCWoo_Cart" );' )
);
