<?php
/**
 * Module Checkout
 *
 * @package Live Composer - WooCommerce integration
 */

// Prevent direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	header( 'HTTP/1.0 403 Forbidden' );
	exit;
}

/**
 * Module Class
 */
class LCWoo_Checkout extends DSLC_Module {

	/**
	 * Unique module id
	 *
	 * @var string
	 */
	var $module_id;

	/**
	 * Module label to show in the page builder
	 *
	 * @var string
	 */
	var $module_title;

	/**
	 * Module icon name (FontAwesome)
	 *
	 * @var string
	 */
	var $module_icon;

	/**
	 * Section in the modules panel that includes this module
	 *
	 * @var string
	 */
	var $module_category;

	/**
	 * Exclude from main listing
	 *
	 * @var string
	 */
	var $exclude_from_main_listing;

	/**
	 * Construct
	 */
	function __construct() {

		$this->module_id = 'LCWoo_Checkout';
		$this->module_title = __( 'Checkout', 'lc-woo-integration' );
		$this->module_icon = 'check';
		$this->module_category = 'Woo Checkout';
		$this->exclude_from_main_listing = true;
	}

	/**
	 * Options
	 */
	function options() {
		$options = array(

			array(
				'label' => __( 'Show On', 'lc-woo-integration' ),
				'id' => 'css_show_on',
				'std' => 'desktop tablet phone',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Desktop', 'lc-woo-integration' ),
						'value' => 'desktop',
					),
					array(
						'label' => __( 'Tablet', 'lc-woo-integration' ),
						'value' => 'tablet',
					),
					array(
						'label' => __( 'Phone', 'lc-woo-integration' ),
						'value' => 'phone',
					),
				),
			),
			array(
				'label' => __( 'Error-Proof Mode', 'lc_masterslider' ),
				'id' => 'error_proof_mode',
				'std' => 'active',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Enabled', 'lc_masterslider' ),
						'value' => 'active',
					),
				),
				'help' => __( 'Some JavaScript code and shortcodes can break the page editing.<br> Use <b>Error-Proof Mode</b> to make it work.', 'lc_masterslider' ),
				'visibility' => 'hidden',
			),

			/**
			 * Info
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_info_bg_color',
				'std' => '#3D9CD2',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_info_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_info_border_color',
					'std' => '#3384B2',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-info',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_info_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-info',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_info_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-info',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_info_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-info',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_info_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_info_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_info_color',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-info',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_info_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-info',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_info_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-info',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_info_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-info',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_info_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-info',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Link - Color', 'lc-woo-integration' ),
					'id' => 'css_info_link_color',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-info a',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Link - Color: Hover', 'lc-woo-integration' ),
					'id' => 'css_info_link_color_hover',
					'std' => '#c2d3e5',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-info a:hover',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Link - Font Weight', 'lc-woo-integration' ),
					'id' => 'css_info_link_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-info a',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Info', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_info_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),

			/**
			 * Info > Text
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_info_text_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login, .lcwoo-checkout form.checkout_coupon',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Info > Text', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_info_text_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info > Text', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_info_text_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login, .lcwoo-checkout form.checkout_coupon',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_info_text_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login, .lcwoo-checkout form.checkout_coupon',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_info_text_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login, .lcwoo-checkout form.checkout_coupon',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_info_text_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login, .lcwoo-checkout form.checkout_coupon',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_info_text_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info > Text', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_info_text_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info > Text', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_info_text_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login p, .lcwoo-checkout form.checkout_coupon',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_info_text_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login p, .lcwoo-checkout form.checkout_coupon',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_info_text_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login p, .lcwoo-checkout form.checkout_coupon',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_info_text_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login p, .lcwoo-checkout form.checkout_coupon',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_info_text_line_height',
					'std' => '22',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login p, .lcwoo-checkout form.checkout_coupon',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Link - Color', 'lc-woo-integration' ),
					'id' => 'css_info_text_link_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login p a, .lcwoo-checkout form.checkout_coupon a',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Link - Color', 'lc-woo-integration' ),
					'id' => 'css_info_text_link_hover_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login p a:hover, .lcwoo-checkout form.checkout_coupon a',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Link - Font Weight', 'lc-woo-integration' ),
					'id' => 'css_info_text_link_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login p a, .lcwoo-checkout form.checkout_coupon a',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_info_text_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info > Text', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_info_text_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info > Text', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_info_text_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login p, .lcwoo-checkout form.checkout_coupon p',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_info_text_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login p, .lcwoo-checkout form.checkout_coupon p',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_info_text_margin_bottom',
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login p, .lcwoo-checkout form.checkout_coupon p',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_info_text_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login p, .lcwoo-checkout form.checkout_coupon p',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_info_text_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info > Text', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_info_text_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info > Text', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_info_text_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login, .lcwoo-checkout form.checkout_coupon',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_info_text_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login, .lcwoo-checkout form.checkout_coupon',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_info_text_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login, .lcwoo-checkout form.checkout_coupon',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_info_text_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login, .lcwoo-checkout form.checkout_coupon',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Text', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_info_text_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info > Text', 'lc-woo-integration' ),
			),

			/**
			 * Info > Label
			 */

			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_info_label_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info > Label', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_info_label_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login label, .lcwoo-checkout form.checkout_coupon label',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Info > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Color - Required', 'lc-woo-integration' ),
					'id' => 'css_info_label_required_color',
					'std' => '#FF0000',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login label span.required, .lcwoo-checkout form.checkout_coupon label span.required',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Info > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_info_label_font_size',
					'std' => '16',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login label, .lcwoo-checkout form.checkout_coupon label',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_info_label_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login label, .lcwoo-checkout form.checkout_coupon label',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Info > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_info_label_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login label, .lcwoo-checkout form.checkout_coupon label',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Info > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_info_label_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login label, .lcwoo-checkout form.checkout_coupon label',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Label', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_info_label_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_info_label_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info > Label', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_info_label_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login label, .lcwoo-checkout form.checkout_coupon label',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Info > Label', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_info_label_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login label, .lcwoo-checkout form.checkout_coupon label',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Info > Label', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_info_label_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login label, .lcwoo-checkout form.checkout_coupon label',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Info > Label', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_info_label_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login label, .lcwoo-checkout form.checkout_coupon label',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Info > Label', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_info_label_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info > Label', 'lc-woo-integration' ),
			),

			/**
			 * Info > Input
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_info_input_bg_color',
				'std' => '#EFEFEF',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Info > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_info_input_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info > Input', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_info_input_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Info > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_info_input_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_info_input_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_info_input_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Info > Input', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_info_input_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_info_input_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info > Input', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_info_input_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Info > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_info_input_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_info_input_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Info > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_info_input_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Info > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_info_input_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Input', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_info_input_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_info_input_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info > Input', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_info_input_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_info_input_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_info_input_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Input', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_info_input_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Input', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_info_input_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info > Input', 'lc-woo-integration' ),
			),

			/**
			 * Info > Button
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_info_button_bg_color',
				'std' => '#EF510E',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Info > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color: Hover', 'lc-woo-integration' ),
				'id' => 'css_info_button_bg_hover_color',
				'std' => '#EF510E',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit]:hover, .lcwoo-checkout form.checkout_coupon input[type=submit]:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Info > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_info_button_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_info_button_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_info_button_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_info_button_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_info_button_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_info_button_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_info_button_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_info_button_color',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_info_button_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_info_button_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_info_button_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_info_button_line_height',
					'std' => '18',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_info_button_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_info_button_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_info_button_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_info_button_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_info_button_margin_bottom',
					'std' => '5',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_info_button_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_info_button_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_info_button_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Info > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_info_button_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '12',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_info_button_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_info_button_padding_bottom',
					'onlypositive' => true,
					'std' => '12',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_info_button_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Info > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_info_button_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Info > Button', 'lc-woo-integration' ),
			),

			/**
			 * Notice
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_notice_bg_color',
				'std' => '#E2401C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Notice', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_notice_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Notice', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_notice_border_color',
					'std' => '#C03718',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_notice_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_notice_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_notice_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_notice_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Notice', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_notice_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Notice', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_notice_color',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_notice_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_notice_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_notice_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_notice_line_height',
					'std' => '29',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-error',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Notice', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_notice_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Notice', 'lc-woo-integration' ),
			),

			/**
			 * Form
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_form_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Form', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_form_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_form_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Form', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_form_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_form_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_form_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Form', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_form_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_form_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Form', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_form_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Form', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_form_margin_bottom',
					'std' => '40',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Form', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_form_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Form', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_form_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_form_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_form_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_form_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_form_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_form_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form', 'lc-woo-integration' ),
			),

			/**
			 * Form > Title
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_form_title_text_align',
				'std' => 'left',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 h3, .lcwoo-checkout form.woocommerce-checkout .col-2 h3',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Form > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_title_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_form_title_color',
					'std' => '#484C51',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 h3, .lcwoo-checkout form.woocommerce-checkout .col-2 h3',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_form_title_font_size',
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 h3, .lcwoo-checkout form.woocommerce-checkout .col-2 h3',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_form_title_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 h3, .lcwoo-checkout form.woocommerce-checkout .col-2 h3',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_form_title_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 h3, .lcwoo-checkout form.woocommerce-checkout .col-2 h3',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_form_title_line_height',
					'std' => '28',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 h3, .lcwoo-checkout form.woocommerce-checkout .col-2 h3',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_title_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_title_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_form_title_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 h3, .lcwoo-checkout form.woocommerce-checkout .col-2 h3',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_form_title_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 h3, .lcwoo-checkout form.woocommerce-checkout .col-2 h3',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_form_title_margin_bottom',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 h3, .lcwoo-checkout form.woocommerce-checkout .col-2 h3',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_form_title_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 h3, .lcwoo-checkout form.woocommerce-checkout .col-2 h3',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Form > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_title_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Title', 'lc-woo-integration' ),
			),

			/**
			 * Form > Label
			 */

			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_title_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Label', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_form_label_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 p label, .lcwoo-checkout form.woocommerce-checkout .col-2 p label',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Required - Color', 'lc-woo-integration' ),
					'id' => 'css_form_label_required_color',
					'std' => '#FF0000',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 p label abbr.required, .lcwoo-checkout form.woocommerce-checkout .col-2 p label abbr.required',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_form_label_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 p label, .lcwoo-checkout form.woocommerce-checkout .col-2 p label',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_form_label_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 p label, .lcwoo-checkout form.woocommerce-checkout .col-2 p label',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_form_label_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 p label, .lcwoo-checkout form.woocommerce-checkout .col-2 p label',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_form_label_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 p label, .lcwoo-checkout form.woocommerce-checkout .col-2 p label',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_title_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_label_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Label', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_form_label_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 p label, .lcwoo-checkout form.woocommerce-checkout .col-2 p label',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_form_label_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 p label, .lcwoo-checkout form.woocommerce-checkout .col-2 p label',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_form_label_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 p label, .lcwoo-checkout form.woocommerce-checkout .col-2 p label',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_form_label_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 p label, .lcwoo-checkout form.woocommerce-checkout .col-2 p label',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Form > Label', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_label_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Label', 'lc-woo-integration' ),
			),

			/**
			 * Form > Input/Textarea
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_form_input_bg_color',
				'std' => '#EFEFEF',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_form_input_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_form_input_border_color',
					'std' => '#D1D1D1',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_form_input_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_form_input_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_form_input_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_form_input_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_input_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_form_input_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_form_input_font_size',
					'std' => '16',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_form_input_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_form_input_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_form_input_line_height',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_input_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Min-Height Textarea', 'lc-woo-integration' ),
				'id' => 'css_form_input_min_height',
				'std' => '50',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
				'affect_on_change_rule' => 'min-height',
				'section' => 'styling',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
				'min' => 50,
				'max' => 400,
				'ext' => 'px',
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_input_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_form_input_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_form_input_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_form_input_margin_bottom',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_form_input_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_input_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_form_input_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_form_input_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_form_input_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_form_input_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_form_input_padding_left',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_form_input_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),

			/**
			 * Form > Select
			 */

			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_select_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Select', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_form_select_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.select2',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Select', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_form_select_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.select2',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Form > Select', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_form_select_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.select2',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Form > Select', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_select_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_select_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Select', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_form_select_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.select2',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Form > Select', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_form_select_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.select2',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Form > Select', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_form_select_margin_bottom',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.select2',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Form > Select', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_form_select_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.select2',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Form > Select', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_select_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Select', 'lc-woo-integration' ),
			),

			/**
			 * Form > Account
			 */

			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_account_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Account', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_form_account_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout .create-account p',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Form > Account', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_form_account_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout .create-account p',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Account', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_form_account_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout .create-account p',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Form > Account', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_form_account_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout .create-account p',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Form > Account', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_form_account_line_height',
					'std' => '22',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout .create-account p',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Form > Account', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_form_account_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Account', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_account_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Form > Account', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_form_account_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout .create-account p',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Form > Account', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_form_account_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout .create-account p',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Form > Account', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_form_account_margin_bottom',
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout .create-account p',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Form > Account', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_form_account_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo-checkout .create-account p',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Form > Account', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_form_account_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Form > Account', 'lc-woo-integration' ),
			),

			/**
			 * Review
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_review_border_color',
					'std' => '#000000',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Review', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_review_border_width',
					'std' => '3',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_review_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_review_border_trbl',
					'std' => 'right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Review', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_review_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_review_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Review', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_review_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Review', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_review_margin_bottom',
					'std' => '40',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Review', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_review_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Review', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_review_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_review_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_review_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_review_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_review_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review', 'lc-woo-integration' ),
			),

			/**
			 * Review > Title
			 */

			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_review_title_text_align',
				'std' => 'left',
				'type' => 'text_align',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_title_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_title_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_review_title_border_color',
					'std' => '#000000',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'h3#order_review_heading',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Review > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_review_title_border_width',
					'std' => '3',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'h3#order_review_heading',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_review_title_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'h3#order_review_heading',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_review_title_border_trbl',
					'std' => 'top right left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => 'h3#order_review_heading',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Review > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_title_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_title_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_review_title_color',
					'std' => '#484C51',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'h3#order_review_heading',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Review > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_review_title_font_size',
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'h3#order_review_heading',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_review_title_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => 'h3#order_review_heading',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Review > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_review_title_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'h3#order_review_heading',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Review > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_review_title_line_height',
					'std' => '28',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'h3#order_review_heading',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_title_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_title_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_review_title_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'h3#order_review_heading',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_review_title_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'h3#order_review_heading',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_review_title_padding_bottom',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'h3#order_review_heading',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_review_title_padding_left',
					'onlypositive' => true,
					'std' => '20',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'h3#order_review_heading',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_title_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_review_title_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_review_title_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'h3#order_review_heading',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Review > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_review_title_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'h3#order_review_heading',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Review > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_review_title_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'h3#order_review_heading',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Review > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_review_title_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => 'h3#order_review_heading',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Review > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_review_title_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),

			/**
			 * Review > Shop Table > Title
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_title_border_color',
					'std' => '#c7c7c7',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_title_border_width',
					'std' => '2',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_title_border_trbl',
					'std' => 'bottom',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_title_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_title_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_title_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_title_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_title_line_height',
					'std' => '21',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Text Transform', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_title_text_transform',
					'std' => 'uppercase',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => __( 'None', 'lc-woo-integration' ),
							'value' => 'none',
						),
						array(
							'label' => __( 'Capitalize', 'lc-woo-integration' ),
							'value' => 'capitalize',
						),
						array(
							'label' => __( 'Uppercase', 'lc-woo-integration' ),
							'value' => 'uppercase',
						),
						array(
							'label' => __( 'Lowercase', 'lc-woo-integration' ),
							'value' => 'lowercase',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
					'affect_on_change_rule' => 'text-transform',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_title_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_title_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_title_padding_bottom',
					'onlypositive' => true,
					'std' => '10',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_title_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Title', 'lc-woo-integration' ),
			),

			/**
			 * Review > Shop Table > Item
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_item_bg_color',
				'std' => 'rgb(246, 246, 246)',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_item_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_item_border_color',
					'std' => '#c4c4c4',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_item_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_item_border_trbl',
					'std' => 'top',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_item_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_item_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_item_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_item_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_item_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_item_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_item_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_item_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_item_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_item_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '8',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_item_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_item_padding_bottom',
					'onlypositive' => true,
					'std' => '8',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_item_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_item_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Item', 'lc-woo-integration' ),
			),

			/**
			 * Review > Shop Table > Variation
			 */

			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_variation_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Variation', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color - One', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_variation_dt_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name dt',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Variation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Color - Two', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_variation_dd_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name dd',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Variation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_variation_dt_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Variation', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Font Weight - One', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_variation_dd_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name dt',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Variation', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Weight - Two', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_variation_font_weight',
					'std' => '500',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name dd',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Variation', 'lc-woo-integration' ),
					'ext' => '',
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_variation_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Variation', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_variation_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Variation', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_variation_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Variation', 'lc-woo-integration' ),
			),

			/**
			 * Review > Shop Table > Cart > Title
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_border_color',
					'std' => '#c4c4c4',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td, .woocommerce-checkout-review-order table tfoot tr th',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td, .woocommerce-checkout-review-order table tfoot tr th',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_border_trbl',
					'std' => 'top',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td, .woocommerce-checkout-review-order table tfoot tr th',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_title_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr th',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_title_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr th',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_title_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr th',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_title_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr th',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_title_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr th',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_title_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_title_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '9',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr th',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_title_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr th',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_title_padding_bottom',
					'onlypositive' => true,
					'std' => '9',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr th',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_title_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr th',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_title_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_margin_bottom',
					'std' => '40',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),

			/**
			 * Review > Shop Table > Cart > Item
			 */

			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_item_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_item_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_item_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_item_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_item_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_item_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_item_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_item_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_item_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '9',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_item_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_item_padding_bottom',
					'onlypositive' => true,
					'std' => '9',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_review_shop_table_cart_item_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_item_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),

			/**
			 * Review > Payment
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_payment_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_payment_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_review_payment_border_color',
					'std' => 'rgb(218, 213, 213)',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_review_payment_border_width',
					'std' => '3',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_review_payment_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_review_payment_border_trbl',
					'std' => 'top',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_payment_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_payment_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_review_payment_color',
					'std' => '#000',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment ul.payment_methods li',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_review_payment_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment ul.payment_methods li',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_review_payment_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment ul.payment_methods li',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_review_payment_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order .payment_methods',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_review_payment_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment ul.payment_methods li',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_payment_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_payment_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_review_payment_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_review_payment_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_review_payment_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_review_payment_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_payment_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),

			/**
			 * Review > Payment > Label
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_bg_color',
				'std' => '#e8e8e8',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_border_color',
					'std' => 'rgb(218, 213, 213)',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_border_trbl',
					'std' => 'bottom',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Color - Link', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_link_color',
					'std' => '#000000',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment label a',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Color - Link: Hover', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_link_hover_color',
					'std' => '#000000',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment label a:hover',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight - Link', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_link_font_weight',
					'std' => '500',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment label a',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '6',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_padding_left',
					'onlypositive' => true,
					'std' => '6',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Img - Height', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_paypal_img_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label img',
				'affect_on_change_rule' => 'height',
				'section' => 'styling',
				'min' => 1,
				'max' => 100,
				'ext' => 'px',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin - Img', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_paypal_img_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_paypal_img_margin_top',
					'std' => '13',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label img',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_paypal_img_margin_right',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label img',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_paypal_img_margin_bottom',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label img',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_review_payment_label_paypal_img_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label img',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin - Img', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_paypal_img_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),

			/**
			 * Review > Payment > Box
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_bg_color',
				'std' => '#F1F1F1',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_review_payment_box_border_color',
					'std' => 'rgb(218, 213, 213)',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_review_payment_box_border_width',
					'std' => '1',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_review_payment_box_border_trbl',
					'std' => 'top',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_review_payment_box_color',
					'std' => '#60646C',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_review_payment_box_font_size',
					'std' => '14',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_review_payment_box_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_review_payment_box_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_review_payment_box_line_height',
					'std' => '22',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_review_payment_box_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_review_payment_box_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_review_payment_box_padding_bottom',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_review_payment_box_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),

			/**
			 * Review > Term
			 */

			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_term_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Term', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_review_term_color',
					'std' => '#43454b',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order .terms label',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Review > Term', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Color - Link', 'lc-woo-integration' ),
					'id' => 'css_review_term_link_color',
					'std' => '#000000',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment .place-order .terms label a',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Review > Term', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Color: Hover - Link', 'lc-woo-integration' ),
					'id' => 'css_review_term_link_color_hover',
					'std' => '#b81313',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment .place-order .terms label a:hover',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Review > Term', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_review_term_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order .terms label',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Term', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_review_term_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order .terms label',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Review > Term', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight - Link', 'lc-woo-integration' ),
					'id' => 'css_review_term_link_font_weight',
					'std' => '400',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.woocommerce-checkout-review-order #payment .place-order .terms label a',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Review > Term', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_review_term_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order .terms label',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Review > Term', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_review_term_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order .terms label',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Term', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_term_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Term', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_review_term_margin_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Term', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Margin Top', 'lc-woo-integration' ),
					'id' => 'css_review_term_margin_top',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order p.terms',
					'affect_on_change_rule' => 'margin-top',
					'section' => 'styling',
					'tab' => __( 'Review > Term', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Right', 'lc-woo-integration' ),
					'id' => 'css_review_term_margin_right',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order p.terms',
					'affect_on_change_rule' => 'margin-right',
					'section' => 'styling',
					'tab' => __( 'Review > Term', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
					'id' => 'css_review_term_margin_bottom',
					'std' => '5',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order p.terms',
					'affect_on_change_rule' => 'margin-bottom',
					'section' => 'styling',
					'tab' => __( 'Review > Term', 'lc-woo-integration' ),
					'ext' => 'px',
				),
				array(
					'label' => __( 'Margin Left', 'lc-woo-integration' ),
					'id' => 'css_review_term_margin_left',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order p.terms',
					'affect_on_change_rule' => 'margin-left',
					'section' => 'styling',
					'tab' => __( 'Review > Term', 'lc-woo-integration' ),
					'ext' => 'px',
				),
			array(
				'label' => __( 'Margin', 'lc-woo-integration' ),
				'id' => 'css_review_term_margin_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Term', 'lc-woo-integration' ),
			),

			/**
			 * Review > Place Order
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_bg_color',
				'std' => '#ebe9eb',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_review_place_order_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_review_place_order_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_review_place_order_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_review_place_order_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_review_place_order_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_review_place_order_padding_bottom',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_review_place_order_padding_left',
					'onlypositive' => true,
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
			),

			/**
			 * Review > Place Order > Button
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_button_bg_color',
				'std' => '#000000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG Color: Hover', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_button_bg_hover_color',
				'std' => '#000000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_button_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_review_place_order_button_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order input[type=submit]',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
					'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_review_place_order_button_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order input[type=submit]',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_review_place_order_button_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order input[type=submit]',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_review_place_order_button_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order input[type=submit]',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
					'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_button_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_button_font_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Color', 'lc-woo-integration' ),
					'id' => 'css_review_place_order_button_color',
					'std' => '#ffffff',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order input[type=submit]',
					'affect_on_change_rule' => 'color',
					'section' => 'styling',
					'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Size', 'lc-woo-integration' ),
					'id' => 'css_review_place_order_button_font_size',
					'std' => '15',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order input[type=submit]',
					'affect_on_change_rule' => 'font-size',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Weight', 'lc-woo-integration' ),
					'id' => 'css_review_place_order_button_font_weight',
					'std' => '300',
					'type' => 'select',
					'choices' => array(
						array(
							'label' => '100 - Thin',
							'value' => '100',
						),
						array(
							'label' => '200 - Extra Light',
							'value' => '200',
						),
						array(
							'label' => '300 - Light',
							'value' => '300',
						),
						array(
							'label' => '400 - Normal',
							'value' => '400',
						),
						array(
							'label' => '500 - Medium',
							'value' => '500',
						),
						array(
							'label' => '600 - Semi Bold',
							'value' => '600',
						),
						array(
							'label' => '700 - Bold',
							'value' => '700',
						),
						array(
							'label' => '800 - Extra Bold',
							'value' => '800',
						),
						array(
							'label' => '900 - Black',
							'value' => '900',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order input[type=submit]',
					'affect_on_change_rule' => 'font-weight',
					'section' => 'styling',
					'ext' => '',
					'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Font Family', 'lc-woo-integration' ),
					'id' => 'css_review_place_order_button_font_family',
					'std' => '',
					'type' => 'font',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order input[type=submit]',
					'affect_on_change_rule' => 'font-family',
					'section' => 'styling',
					'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Line Height', 'lc-woo-integration' ),
					'id' => 'css_review_place_order_button_line_height',
					'std' => '24',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.place-order input[type=submit]',
					'affect_on_change_rule' => 'line-height',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Font', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_button_font_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
			),

			/**
			 * Responsive Tablet
			 */

/*			array(
				'label' => __( 'Responsive Styling', 'lc-woo-integration' ),
				'id' => 'css_res_t',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Text - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_text_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login p, .lcwoo-checkout form.checkout_coupon',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Text - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_text_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login p, .lcwoo-checkout form.checkout_coupon',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Text - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_text_margin_bottom',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login p, .lcwoo-checkout form.checkout_coupon p',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Text - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_text_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login, .lcwoo-checkout form.checkout_coupon',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Text - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_text_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login, .lcwoo-checkout form.checkout_coupon',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Label - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_label_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login label, .lcwoo-checkout form.checkout_coupon label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Label - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_label_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login label, .lcwoo-checkout form.checkout_coupon label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Label - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_label_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login label, .lcwoo-checkout form.checkout_coupon label',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Input - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_input_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Input - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_input_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Input - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_input_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Input - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_input_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_button_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_button_line_height',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Button - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_button_margin_bottom',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Button - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_button_padding_vertical',
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Button - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_button_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Notice - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_notice_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Notice - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_notice_line_height',
				'std' => '29',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_title_font_size',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 h3, .lcwoo-checkout form.woocommerce-checkout .col-2 h3',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_title_line_height',
				'std' => '28',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 h3, .lcwoo-checkout form.woocommerce-checkout .col-2 h3',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_title_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 h3, .lcwoo-checkout form.woocommerce-checkout .col-2 h3',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Label - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_label_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 p label, .lcwoo-checkout form.woocommerce-checkout .col-2 p label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Label - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_label_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 p label, .lcwoo-checkout form.woocommerce-checkout .col-2 p label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Label - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_label_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 p label, .lcwoo-checkout form.woocommerce-checkout .col-2 p label',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_input_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_input_line_height',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_input_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_input_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_input_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_select_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-1 select, .lcwoo-checkout form.woocommerce-checkout .col-2 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-2 select',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_select_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-1 select, .lcwoo-checkout form.woocommerce-checkout .col-2 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-2 select',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_select_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-1 select, .lcwoo-checkout form.woocommerce-checkout .col-2 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-2 select',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_select_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-1 select, .lcwoo-checkout form.woocommerce-checkout .col-2 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-2 select',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_select_padding_horizontal',
				'std' => '7',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-1 select, .lcwoo-checkout form.woocommerce-checkout .col-2 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-2 select',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Account - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_account_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout .create-account p',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Account - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_account_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout .create-account p',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Account - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_account_margin_bottom',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout .create-account p',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_title_font_size',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_title_line_height',
				'std' => '28',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_title_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_title_padding_horizontal',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_title_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_title_line_height',
				'std' => '21',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Title - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_title_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Title - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Item - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_item_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Item - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_item_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Item - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_item_padding_vertical',
				'std' => '8',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Item - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_item_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Variation - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_variation_dt_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Review > Shop Table > Variation - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_variation_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_title_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_title_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Item - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_item_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Item - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_item_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Item - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_item_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Item - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_item_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment ul.payment_methods li',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment ul.payment_methods li',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_label_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_label_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_label_padding_horizontal',
				'std' => '6',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label > Img - Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_label_paypal_img_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label img',
				'affect_on_change_rule' => 'height',
				'section' => 'responsive',
				'min' => 1,
				'max' => 100,
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label > Img - Margin Top', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_label_paypal_img_margin_top',
				'std' => '13',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label img',
				'affect_on_change_rule' => 'margin-top',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label > Img - Margin Right', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_label_paypal_img_margin_right',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label img',
				'affect_on_change_rule' => 'margin-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Box - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_box_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Box - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_box_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Box - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_box_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Box - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_box_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Term - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_term_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order .terms label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Term - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_term_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order .terms label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Term - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_term_margin_bottom',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order p.terms',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Place Order - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_place_order_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Place Order - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_place_order_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Place Order > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_place_order_button_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Place Order > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_place_order_button_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),*/

			/**
			 * Responsive Phone
			 */

/*			array(
				'label' => __( 'Responsive Styling', 'lc-woo-integration' ),
				'id' => 'css_res_p',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Text - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_text_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login p, .lcwoo-checkout form.checkout_coupon',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Text - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_text_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login p, .lcwoo-checkout form.checkout_coupon',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Text - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_text_margin_bottom',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login p, .lcwoo-checkout form.checkout_coupon p',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Text - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_text_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login, .lcwoo-checkout form.checkout_coupon',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Text - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_text_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login, .lcwoo-checkout form.checkout_coupon',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Label - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_label_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login label, .lcwoo-checkout form.checkout_coupon label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Label - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_label_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login label, .lcwoo-checkout form.checkout_coupon label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Label - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_label_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login label, .lcwoo-checkout form.checkout_coupon label',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Input - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_input_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Input - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_input_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Input - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_input_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Input - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_input_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=text], .lcwoo-checkout form.login input[type=password], .lcwoo-checkout form.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_button_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_button_line_height',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Button - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_button_margin_bottom',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Button - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_button_padding_vertical',
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Button - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_button_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.login input[type=submit], .lcwoo-checkout form.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Notice - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_notice_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Notice - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_notice_line_height',
				'std' => '29',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1, .lcwoo-checkout form.woocommerce-checkout .col-2',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_title_font_size',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 h3, .lcwoo-checkout form.woocommerce-checkout .col-2 h3',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_title_line_height',
				'std' => '28',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 h3, .lcwoo-checkout form.woocommerce-checkout .col-2 h3',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_title_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 h3, .lcwoo-checkout form.woocommerce-checkout .col-2 h3',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Label - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_label_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 p label, .lcwoo-checkout form.woocommerce-checkout .col-2 p label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Label - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_label_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 p label, .lcwoo-checkout form.woocommerce-checkout .col-2 p label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Label - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_label_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 p label, .lcwoo-checkout form.woocommerce-checkout .col-2 p label',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_input_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_input_line_height',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_input_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_input_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_input_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 input, .lcwoo-checkout form.woocommerce-checkout .col-2 input, .lcwoo-checkout form.woocommerce-checkout .col-2 textarea',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_select_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-1 select, .lcwoo-checkout form.woocommerce-checkout .col-2 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-2 select',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_select_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-1 select, .lcwoo-checkout form.woocommerce-checkout .col-2 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-2 select',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_select_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-1 select, .lcwoo-checkout form.woocommerce-checkout .col-2 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-2 select',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_select_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-1 select, .lcwoo-checkout form.woocommerce-checkout .col-2 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-2 select',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_select_padding_horizontal',
				'std' => '7',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout form.woocommerce-checkout .col-1 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-1 select, .lcwoo-checkout form.woocommerce-checkout .col-2 .select2-container a, .lcwoo-checkout form.woocommerce-checkout .col-2 select',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Account - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_account_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout .create-account p',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Account - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_account_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout .create-account p',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Account - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_account_margin_bottom',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo-checkout .create-account p',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_title_font_size',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_title_line_height',
				'std' => '28',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_title_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_title_padding_horizontal',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_title_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_title_line_height',
				'std' => '21',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Title - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_title_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Title - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table thead tr th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Item - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_item_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Item - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_item_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Item - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_item_padding_vertical',
				'std' => '8',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Item - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_item_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tbody tr td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Variation - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_variation_dt_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Review > Shop Table > Variation - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_variation_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_title_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_title_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Item - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_item_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Item - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_item_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Item - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_item_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Item - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_item_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order table tfoot tr td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment ul.payment_methods li',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment ul.payment_methods li',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_label_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_label_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_label_padding_horizontal',
				'std' => '6',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label > Img - Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_label_paypal_img_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label img',
				'affect_on_change_rule' => 'height',
				'section' => 'responsive',
				'min' => 1,
				'max' => 100,
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label > Img - Margin Top', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_label_paypal_img_margin_top',
				'std' => '13',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label img',
				'affect_on_change_rule' => 'margin-top',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label > Img - Margin Right', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_label_paypal_img_margin_right',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label img',
				'affect_on_change_rule' => 'margin-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Box - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_box_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Box - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_box_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Box - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_box_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Box - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_box_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li .payment_box',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Term - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_term_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order .terms label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Term - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_term_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order .terms label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Term - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_term_margin_bottom',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order p.terms',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Place Order - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_place_order_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Place Order - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_place_order_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Place Order > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_place_order_button_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Place Order > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_place_order_button_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),*/

		);

		$options = array_merge( $options, $this->shared_options( 'animation_options' ) );
		$options = array_merge( $options, $this->presets_options() );

		return apply_filters( 'dslc_module_options', $options, $this->module_id );
	}

	/**
	 * Module HTML output.
	 *
	 * @param  array $options Module options to fill the module template.
	 */
	function output( $options ) {

		$this->module_start( $options );

		global $dslc_active;

		if ( isset( $_POST['dslc_post_id'] ) ) {
			$page_id = $_POST['dslc_post_id'];
		} elseif ( isset( $_GET['dslc_post_id'] ) ) {
			$page_id = $_GET['dslc_post_id'];
		} else {
			$page_id = get_the_ID();
		}

		if ( $dslc_active && is_user_logged_in() && current_user_can( DS_LIVE_COMPOSER_CAPABILITY ) ) {
			$dslc_is_admin = true;
		} else {
			$dslc_is_admin = false;
		}

		// Check if Error-Proof mode activated in module options.
		$error_proof_mode = false;
		if ( isset( $options['error_proof_mode'] ) && '' !== $options['error_proof_mode'] ) {
			$error_proof_mode = true;
		}

		// Check if module rendered via ajax call.
		$ajax_module_render = true;
		if ( isset( $options['module_render_nonajax'] ) ) {
			$ajax_module_render = false;
		}

		// Decide if we should render the module or wait for the page refresh.
		$render_code = true;
		if ( $dslc_is_admin && $error_proof_mode && $ajax_module_render ) {
			$render_code = false;
		}

		if ( is_checkout() || wc_get_page_id( 'checkout' ) == $page_id ) {

			if ( $render_code ) {
				$output = '<div class="lcwoo-checkout">' . do_shortcode( '[woocommerce_checkout]' ) . '</div>';
			} else {
				$output = '<div class="dslc-notification dslc-green">' . __( 'Please save and update the page to see changes.', 'lc-woo-integration' ) . '</div>';
			}

			echo $output;

		} else {
			if ( $dslc_is_admin ) {
			?>
			<div class="dslc-notification dslc-red">
				<?php esc_html_e( 'This module will be available when you choose the Checkout page in WooCommerce. ( WooCommerce -> Settings -> Checkout -> Checkout Page )', 'lc-woo-integration' ); ?>
			</div>
		<?php }
		}

		$this->module_end( $options );
	}
}

/**
 * Register Module
 */
add_action('dslc_hook_register_modules',
	create_function( '', 'return dslc_register_module( "LCWoo_Checkout" );' )
);
